#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .species import species as species_cls
from .reactions import reactions as reactions_cls
from .reaction_mechs import reaction_mechs as reaction_mechs_cls
from .density import density as density_cls
from .specific_heat import specific_heat as specific_heat_cls
from .thermal_conductivity import thermal_conductivity as thermal_conductivity_cls
from .viscosity import viscosity as viscosity_cls
from .molecular_weight import molecular_weight as molecular_weight_cls
from .mass_diffusivity import mass_diffusivity as mass_diffusivity_cls
from .thermal_diffusivity import thermal_diffusivity as thermal_diffusivity_cls
from .formation_enthalpy import formation_enthalpy as formation_enthalpy_cls
from .formation_entropy import formation_entropy as formation_entropy_cls
from .characteristic_vibrational_temperature import characteristic_vibrational_temperature as characteristic_vibrational_temperature_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .lennard_jones_length import lennard_jones_length as lennard_jones_length_cls
from .lennard_jones_energy import lennard_jones_energy as lennard_jones_energy_cls
from .thermal_accom_coefficient import thermal_accom_coefficient as thermal_accom_coefficient_cls
from .velocity_accom_coefficient import velocity_accom_coefficient as velocity_accom_coefficient_cls
from .absorption_coefficient import absorption_coefficient as absorption_coefficient_cls
from .scattering_coefficient import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .therm_exp_coeff import therm_exp_coeff as therm_exp_coeff_cls
from .premix_unburnt_density import premix_unburnt_density as premix_unburnt_density_cls
from .premix_unburnt_temp import premix_unburnt_temp as premix_unburnt_temp_cls
from .premix_adiabatic_temp import premix_adiabatic_temp as premix_adiabatic_temp_cls
from .premix_unburnt_cp import premix_unburnt_cp as premix_unburnt_cp_cls
from .premix_heat_trans_coeff import premix_heat_trans_coeff as premix_heat_trans_coeff_cls
from .premix_laminar_speed import premix_laminar_speed as premix_laminar_speed_cls
from .premix_laminar_thickness import premix_laminar_thickness as premix_laminar_thickness_cls
from .premix_critical_strain import premix_critical_strain as premix_critical_strain_cls
from .premix_heat_of_comb import premix_heat_of_comb as premix_heat_of_comb_cls
from .premix_unburnt_fuel_mf import premix_unburnt_fuel_mf as premix_unburnt_fuel_mf_cls
from .refractive_index import refractive_index as refractive_index_cls
from .latent_heat import latent_heat as latent_heat_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .vaporization_temperature import vaporization_temperature as vaporization_temperature_cls
from .boiling_point import boiling_point as boiling_point_cls
from .volatile_fraction import volatile_fraction as volatile_fraction_cls
from .binary_diffusivity import binary_diffusivity as binary_diffusivity_cls
from .diffusivity_reference_pressure import diffusivity_reference_pressure as diffusivity_reference_pressure_cls
from .vapor_pressure import vapor_pressure as vapor_pressure_cls
from .degrees_of_freedom import degrees_of_freedom as degrees_of_freedom_cls
from .emissivity import emissivity as emissivity_cls
from .scattering_factor import scattering_factor as scattering_factor_cls
from .heat_of_pyrolysis import heat_of_pyrolysis as heat_of_pyrolysis_cls
from .swelling_coefficient import swelling_coefficient as swelling_coefficient_cls
from .burn_stoichiometry import burn_stoichiometry as burn_stoichiometry_cls
from .combustible_fraction import combustible_fraction as combustible_fraction_cls
from .burn_hreact import burn_hreact as burn_hreact_cls
from .burn_hreact_fraction import burn_hreact_fraction as burn_hreact_fraction_cls
from .devolatilization_model import devolatilization_model as devolatilization_model_cls
from .combustion_model import combustion_model as combustion_model_cls
from .averaging_coefficient_t import averaging_coefficient_t as averaging_coefficient_t_cls
from .averaging_coefficient_y import averaging_coefficient_y as averaging_coefficient_y_cls
from .vaporization_model import vaporization_model as vaporization_model_cls
from .thermolysis_model import thermolysis_model as thermolysis_model_cls
from .melting_heat import melting_heat as melting_heat_cls
from .tsolidus import tsolidus as tsolidus_cls
from .tliqidus import tliqidus as tliqidus_cls
from .tmelt import tmelt as tmelt_cls
from .liquidus_slope import liquidus_slope as liquidus_slope_cls
from .partition_coeff import partition_coeff as partition_coeff_cls
from .eutectic_mf import eutectic_mf as eutectic_mf_cls
from .eutectic_temp import eutectic_temp as eutectic_temp_cls
from .solut_exp_coeff import solut_exp_coeff as solut_exp_coeff_cls
from .solid_diffusion import solid_diffusion as solid_diffusion_cls
from .uds_diffusivity import uds_diffusivity as uds_diffusivity_cls
from .dpm_surften import dpm_surften as dpm_surften_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .charge_density import charge_density as charge_density_cls
from .charge import charge as charge_cls
from .speed_of_sound import speed_of_sound as speed_of_sound_cls
from .species_phase import species_phase as species_phase_cls
from .vp_equilib import vp_equilib as vp_equilib_cls
from .critical_temperature import critical_temperature as critical_temperature_cls
from .critical_pressure import critical_pressure as critical_pressure_cls
from .critical_volume import critical_volume as critical_volume_cls
from .acentric_factor import acentric_factor as acentric_factor_cls
from .saturation_pressure import saturation_pressure as saturation_pressure_cls
from .struct_youngs_modulus import struct_youngs_modulus as struct_youngs_modulus_cls
from .struct_poisson_ratio import struct_poisson_ratio as struct_poisson_ratio_cls
from .struct_start_temperature import struct_start_temperature as struct_start_temperature_cls
from .struct_thermal_expansion import struct_thermal_expansion as struct_thermal_expansion_cls
from .atomic_number import atomic_number as atomic_number_cls
from .struct_damping_alpha import struct_damping_alpha as struct_damping_alpha_cls
from .struct_damping_beta import struct_damping_beta as struct_damping_beta_cls

class fluid_child(Group):
    """
    'child_object_type' of fluid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['species', 'reactions', 'reaction_mechs', 'density', 'specific_heat',
         'thermal_conductivity', 'viscosity', 'molecular_weight',
         'mass_diffusivity', 'thermal_diffusivity', 'formation_enthalpy',
         'formation_entropy', 'characteristic_vibrational_temperature',
         'reference_temperature', 'lennard_jones_length',
         'lennard_jones_energy', 'thermal_accom_coefficient',
         'velocity_accom_coefficient', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'therm_exp_coeff', 'premix_unburnt_density', 'premix_unburnt_temp',
         'premix_adiabatic_temp', 'premix_unburnt_cp',
         'premix_heat_trans_coeff', 'premix_laminar_speed',
         'premix_laminar_thickness', 'premix_critical_strain',
         'premix_heat_of_comb', 'premix_unburnt_fuel_mf', 'refractive_index',
         'latent_heat', 'thermophoretic_co', 'vaporization_temperature',
         'boiling_point', 'volatile_fraction', 'binary_diffusivity',
         'diffusivity_reference_pressure', 'vapor_pressure',
         'degrees_of_freedom', 'emissivity', 'scattering_factor',
         'heat_of_pyrolysis', 'swelling_coefficient', 'burn_stoichiometry',
         'combustible_fraction', 'burn_hreact', 'burn_hreact_fraction',
         'devolatilization_model', 'combustion_model',
         'averaging_coefficient_t', 'averaging_coefficient_y',
         'vaporization_model', 'thermolysis_model', 'melting_heat',
         'tsolidus', 'tliqidus', 'tmelt', 'liquidus_slope', 'partition_coeff',
         'eutectic_mf', 'eutectic_temp', 'solut_exp_coeff', 'solid_diffusion',
         'uds_diffusivity', 'dpm_surften', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'magnetic_permeability', 'charge_density', 'charge',
         'speed_of_sound', 'species_phase', 'vp_equilib',
         'critical_temperature', 'critical_pressure', 'critical_volume',
         'acentric_factor', 'saturation_pressure', 'struct_youngs_modulus',
         'struct_poisson_ratio', 'struct_start_temperature',
         'struct_thermal_expansion', 'atomic_number', 'struct_damping_alpha',
         'struct_damping_beta']

    _child_classes = dict(
        species=species_cls,
        reactions=reactions_cls,
        reaction_mechs=reaction_mechs_cls,
        density=density_cls,
        specific_heat=specific_heat_cls,
        thermal_conductivity=thermal_conductivity_cls,
        viscosity=viscosity_cls,
        molecular_weight=molecular_weight_cls,
        mass_diffusivity=mass_diffusivity_cls,
        thermal_diffusivity=thermal_diffusivity_cls,
        formation_enthalpy=formation_enthalpy_cls,
        formation_entropy=formation_entropy_cls,
        characteristic_vibrational_temperature=characteristic_vibrational_temperature_cls,
        reference_temperature=reference_temperature_cls,
        lennard_jones_length=lennard_jones_length_cls,
        lennard_jones_energy=lennard_jones_energy_cls,
        thermal_accom_coefficient=thermal_accom_coefficient_cls,
        velocity_accom_coefficient=velocity_accom_coefficient_cls,
        absorption_coefficient=absorption_coefficient_cls,
        scattering_coefficient=scattering_coefficient_cls,
        scattering_phase_function=scattering_phase_function_cls,
        therm_exp_coeff=therm_exp_coeff_cls,
        premix_unburnt_density=premix_unburnt_density_cls,
        premix_unburnt_temp=premix_unburnt_temp_cls,
        premix_adiabatic_temp=premix_adiabatic_temp_cls,
        premix_unburnt_cp=premix_unburnt_cp_cls,
        premix_heat_trans_coeff=premix_heat_trans_coeff_cls,
        premix_laminar_speed=premix_laminar_speed_cls,
        premix_laminar_thickness=premix_laminar_thickness_cls,
        premix_critical_strain=premix_critical_strain_cls,
        premix_heat_of_comb=premix_heat_of_comb_cls,
        premix_unburnt_fuel_mf=premix_unburnt_fuel_mf_cls,
        refractive_index=refractive_index_cls,
        latent_heat=latent_heat_cls,
        thermophoretic_co=thermophoretic_co_cls,
        vaporization_temperature=vaporization_temperature_cls,
        boiling_point=boiling_point_cls,
        volatile_fraction=volatile_fraction_cls,
        binary_diffusivity=binary_diffusivity_cls,
        diffusivity_reference_pressure=diffusivity_reference_pressure_cls,
        vapor_pressure=vapor_pressure_cls,
        degrees_of_freedom=degrees_of_freedom_cls,
        emissivity=emissivity_cls,
        scattering_factor=scattering_factor_cls,
        heat_of_pyrolysis=heat_of_pyrolysis_cls,
        swelling_coefficient=swelling_coefficient_cls,
        burn_stoichiometry=burn_stoichiometry_cls,
        combustible_fraction=combustible_fraction_cls,
        burn_hreact=burn_hreact_cls,
        burn_hreact_fraction=burn_hreact_fraction_cls,
        devolatilization_model=devolatilization_model_cls,
        combustion_model=combustion_model_cls,
        averaging_coefficient_t=averaging_coefficient_t_cls,
        averaging_coefficient_y=averaging_coefficient_y_cls,
        vaporization_model=vaporization_model_cls,
        thermolysis_model=thermolysis_model_cls,
        melting_heat=melting_heat_cls,
        tsolidus=tsolidus_cls,
        tliqidus=tliqidus_cls,
        tmelt=tmelt_cls,
        liquidus_slope=liquidus_slope_cls,
        partition_coeff=partition_coeff_cls,
        eutectic_mf=eutectic_mf_cls,
        eutectic_temp=eutectic_temp_cls,
        solut_exp_coeff=solut_exp_coeff_cls,
        solid_diffusion=solid_diffusion_cls,
        uds_diffusivity=uds_diffusivity_cls,
        dpm_surften=dpm_surften_cls,
        electric_conductivity=electric_conductivity_cls,
        dual_electric_conductivity=dual_electric_conductivity_cls,
        lithium_diffusivity=lithium_diffusivity_cls,
        magnetic_permeability=magnetic_permeability_cls,
        charge_density=charge_density_cls,
        charge=charge_cls,
        speed_of_sound=speed_of_sound_cls,
        species_phase=species_phase_cls,
        vp_equilib=vp_equilib_cls,
        critical_temperature=critical_temperature_cls,
        critical_pressure=critical_pressure_cls,
        critical_volume=critical_volume_cls,
        acentric_factor=acentric_factor_cls,
        saturation_pressure=saturation_pressure_cls,
        struct_youngs_modulus=struct_youngs_modulus_cls,
        struct_poisson_ratio=struct_poisson_ratio_cls,
        struct_start_temperature=struct_start_temperature_cls,
        struct_thermal_expansion=struct_thermal_expansion_cls,
        atomic_number=atomic_number_cls,
        struct_damping_alpha=struct_damping_alpha_cls,
        struct_damping_beta=struct_damping_beta_cls,
    )

    return_type = "<object object at 0x7fd84557a220>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .smooth_partitioning import smooth_partitioning as smooth_partitioning_cls
from .max_smoothing_iterations import max_smoothing_iterations as max_smoothing_iterations_cls

class smooth(Group):
    """
    Set partition smoothing optimization.
    """

    fluent_name = "smooth"

    child_names = \
        ['smooth_partitioning', 'max_smoothing_iterations']

    _child_classes = dict(
        smooth_partitioning=smooth_partitioning_cls,
        max_smoothing_iterations=max_smoothing_iterations_cls,
    )

    return_type = "<object object at 0x7fc53ff35230>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .relaxation_factor_2 import relaxation_factor as relaxation_factor_cls
from .select_variables import select_variables as select_variables_cls
from .relaxation_options import relaxation_options as relaxation_options_cls

class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['relaxation_factor', 'select_variables', 'relaxation_options']

    _child_classes = dict(
        relaxation_factor=relaxation_factor_cls,
        select_variables=select_variables_cls,
        relaxation_options=relaxation_options_cls,
    )

    return_type = "<object object at 0x7fd82ae39180>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .outer_iterations import outer_iterations as outer_iterations_cls
from .initial_outer_iterations import initial_outer_iterations as initial_outer_iterations_cls
from .instability_detector import instability_detector as instability_detector_cls

class hybrid_nita(Group):
    """
    'hybrid_nita' child.
    """

    fluent_name = "hybrid-nita"

    child_names = \
        ['outer_iterations', 'initial_outer_iterations',
         'instability_detector']

    _child_classes = dict(
        outer_iterations=outer_iterations_cls,
        initial_outer_iterations=initial_outer_iterations_cls,
        instability_detector=instability_detector_cls,
    )

    return_type = "<object object at 0x7fd82ae39680>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .camera import camera as camera_cls
from .display_states import display_states as display_states_cls
from .auto_scale_3 import auto_scale as auto_scale_cls
from .reset_to_default_view import reset_to_default_view as reset_to_default_view_cls
from .delete_view import delete_view as delete_view_cls
from .last_view import last_view as last_view_cls
from .next_view import next_view as next_view_cls
from .list_views import list_views as list_views_cls
from .restore_view import restore_view as restore_view_cls
from .read_views import read_views as read_views_cls
from .save_view import save_view as save_view_cls
from .write_views import write_views as write_views_cls

class views(Group):
    """
    'views' child.
    """

    fluent_name = "views"

    child_names = \
        ['camera', 'display_states']

    command_names = \
        ['auto_scale', 'reset_to_default_view', 'delete_view', 'last_view',
         'next_view', 'list_views', 'restore_view', 'read_views', 'save_view',
         'write_views']

    _child_classes = dict(
        camera=camera_cls,
        display_states=display_states_cls,
        auto_scale=auto_scale_cls,
        reset_to_default_view=reset_to_default_view_cls,
        delete_view=delete_view_cls,
        last_view=last_view_cls,
        next_view=next_view_cls,
        list_views=list_views_cls,
        restore_view=restore_view_cls,
        read_views=read_views_cls,
        save_view=save_view_cls,
        write_views=write_views_cls,
    )

    return_type = "<object object at 0x7fc55413e700>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_2 import name as name_cls
from .report_type import report_type as report_type_cls
from .geometry_4 import geometry as geometry_cls
from .physics_1 import physics as physics_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .phase_26 import phase as phase_cls
from .average_over import average_over as average_over_cls
from .per_zone import per_zone as per_zone_cls
from .old_props import old_props as old_props_cls
from .zone_names_1 import zone_names as zone_names_cls
from .zone_ids import zone_ids as zone_ids_cls

class flux_child(Group):
    """
    'child_object_type' of flux.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'report_type', 'geometry', 'physics',
         'retain_instantaneous_values', 'phase', 'average_over', 'per_zone',
         'old_props', 'zone_names', 'zone_ids']

    _child_classes = dict(
        name=name_cls,
        report_type=report_type_cls,
        geometry=geometry_cls,
        physics=physics_cls,
        retain_instantaneous_values=retain_instantaneous_values_cls,
        phase=phase_cls,
        average_over=average_over_cls,
        per_zone=per_zone_cls,
        old_props=old_props_cls,
        zone_names=zone_names_cls,
        zone_ids=zone_ids_cls,
    )

    return_type = "<object object at 0x7fb5f6195d10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .change_curr_sample import change_curr_sample as change_curr_sample_cls
from .sample import sample as sample_cls

class pick_sample_to_reduce(Command):
    """
    Pick a sample for which to first set-up and then perform the data reduction.
    
    Parameters
    ----------
        change_curr_sample : bool
            'change_curr_sample' child.
        sample : str
            'sample' child.
    
    """

    fluent_name = "pick-sample-to-reduce"

    argument_names = \
        ['change_curr_sample', 'sample']

    _child_classes = dict(
        change_curr_sample=change_curr_sample_cls,
        sample=sample_cls,
    )

    return_type = "<object object at 0x7fc55413fc90>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name import name as name_cls
from .zones import zones as zones_cls

class replace(Command):
    """
    Replace mesh and interpolate data.
    
    Parameters
    ----------
        name : str
            'name' child.
        zones : bool
            'zones' child.
    
    """

    fluent_name = "replace"

    argument_names = \
        ['name', 'zones']

    _child_classes = dict(
        name=name_cls,
        zones=zones_cls,
    )

    return_type = "<object object at 0x7fc5c18a7620>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .type_3 import type as type_cls
from .boundaries import boundaries as boundaries_cls
from .locations import locations as locations_cls

class volumes_child(Group):
    """
    'child_object_type' of volumes.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['type', 'boundaries', 'locations']

    _child_classes = dict(
        type=type_cls,
        boundaries=boundaries_cls,
        locations=locations_cls,
    )

    return_type = "<object object at 0x7fb5f629a890>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .averaged_turbulent_parameters import averaged_turbulent_parameters as averaged_turbulent_parameters_cls
from .turbulent_intensity_1 import turbulent_intensity as turbulent_intensity_cls
from .viscosity_ratio_1 import viscosity_ratio as viscosity_ratio_cls

class turbulent_setting(Group):
    fluent_name = ...
    child_names = ...
    averaged_turbulent_parameters: averaged_turbulent_parameters_cls = ...
    turbulent_intensity: turbulent_intensity_cls = ...
    viscosity_ratio: viscosity_ratio_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .create_zones_from_ccl import create_zones_from_ccl as create_zones_from_ccl_cls
from .read import read as read_cls
from .chemkin_report_each_line import chemkin_report_each_line as chemkin_report_each_line_cls
from .import_fmu import import_fmu as import_fmu_cls

class import_(Group):
    fluent_name = ...
    child_names = ...
    create_zones_from_ccl: create_zones_from_ccl_cls = ...
    command_names = ...

    def read(self, file_type: str, file_name: str):
        """
        'read' command.
        
        Parameters
        ----------
            file_type : str
                'file_type' child.
            file_name : str
                'file_name' child.
        
        """

    def chemkin_report_each_line(self, report_each_line: bool):
        """
        'chemkin_report_each_line' command.
        
        Parameters
        ----------
            report_each_line : bool
                Enable/disable reporting after reading each line.
        
        """

    def import_fmu(self, file_name: str):
        """
        Import a FMU file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .hardcopy_format import hardcopy_format as hardcopy_format_cls
from .hardcopy_options import hardcopy_options as hardcopy_options_cls
from .window_dump_cmd import window_dump_cmd as window_dump_cmd_cls
from .post_format import post_format as post_format_cls
from .current_driver import current_driver as current_driver_cls

class driver_options(Group):
    fluent_name = ...
    child_names = ...
    hardcopy_format: hardcopy_format_cls = ...
    hardcopy_options: hardcopy_options_cls = ...
    window_dump_cmd: window_dump_cmd_cls = ...
    post_format: post_format_cls = ...
    command_names = ...

    def current_driver(self, ):
        """
        'current_driver' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_2 import option as option_cls
from .source_update_every_iteration_enabled import source_update_every_iteration_enabled as source_update_every_iteration_enabled_cls
from .iteration_interval import iteration_interval as iteration_interval_cls

class interaction(Group):
    """
    'interaction' child.
    """

    fluent_name = "interaction"

    child_names = \
        ['option', 'source_update_every_iteration_enabled',
         'iteration_interval']

    _child_classes = dict(
        option=option_cls,
        source_update_every_iteration_enabled=source_update_every_iteration_enabled_cls,
        iteration_interval=iteration_interval_cls,
    )

    return_type = "<object object at 0x7fb66c2e04e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_fast_mode import enable_fast_mode as enable_fast_mode_cls
from .enable_memory_saving_mode import enable_memory_saving_mode as enable_memory_saving_mode_cls
from .disable_warped_face_gradient_correction import disable_warped_face_gradient_correction as disable_warped_face_gradient_correction_cls

class enable(Group):
    """
    'enable' child.
    """

    fluent_name = "enable?"

    child_names = \
        ['enable_fast_mode', 'enable_memory_saving_mode']

    command_names = \
        ['disable_warped_face_gradient_correction']

    _child_classes = dict(
        enable_fast_mode=enable_fast_mode_cls,
        enable_memory_saving_mode=enable_memory_saving_mode_cls,
        disable_warped_face_gradient_correction=disable_warped_face_gradient_correction_cls,
    )

    return_type = "<object object at 0x7fd82ae39c00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .single_precision_coordinates import single_precision_coordinates as single_precision_coordinates_cls
from .binary_legacy_files import binary_legacy_files as binary_legacy_files_cls
from .cff_files import cff_files as cff_files_cls
from .convert_hanging_nodes_during_read import convert_hanging_nodes_during_read as convert_hanging_nodes_during_read_cls
from .async_optimize import async_optimize as async_optimize_cls
from .write_pdat import write_pdat as write_pdat_cls
from .confirm_overwrite import confirm_overwrite as confirm_overwrite_cls
from .auto_save import auto_save as auto_save_cls
from .export import export as export_cls
from .import_ import import_ as import__cls
from .parametric_project import parametric_project as parametric_project_cls
from .cffio_options import cffio_options as cffio_options_cls
from .define_macro import define_macro as define_macro_cls
from .execute_macro import execute_macro as execute_macro_cls
from .read_macros import read_macros as read_macros_cls
from .read_1 import read as read_cls
from .read_case import read_case as read_case_cls
from .read_case_data import read_case_data as read_case_data_cls
from .read_case_setting import read_case_setting as read_case_setting_cls
from .read_data import read_data as read_data_cls
from .read_mesh import read_mesh as read_mesh_cls
from .read_journal import read_journal as read_journal_cls
from .start_journal import start_journal as start_journal_cls
from .stop_journal import stop_journal as stop_journal_cls
from .replace_mesh import replace_mesh as replace_mesh_cls
from .write import write as write_cls
from .read_settings import read_settings as read_settings_cls
from .read_field_functions import read_field_functions as read_field_functions_cls
from .read_injections import read_injections as read_injections_cls
from .read_profile import read_profile as read_profile_cls
from .read_pdf import read_pdf as read_pdf_cls
from .read_isat_table import read_isat_table as read_isat_table_cls
from .show_configuration import show_configuration as show_configuration_cls
from .stop_macro import stop_macro as stop_macro_cls
from .start_transcript import start_transcript as start_transcript_cls
from .stop_transcript import stop_transcript as stop_transcript_cls
from .data_file_options import data_file_options as data_file_options_cls

class file(Group):
    """
    'file' child.
    """

    fluent_name = "file"

    child_names = \
        ['single_precision_coordinates', 'binary_legacy_files', 'cff_files',
         'convert_hanging_nodes_during_read', 'async_optimize', 'write_pdat',
         'confirm_overwrite', 'auto_save', 'export', 'import_',
         'parametric_project', 'cffio_options']

    command_names = \
        ['define_macro', 'execute_macro', 'read_macros', 'read', 'read_case',
         'read_case_data', 'read_case_setting', 'read_data', 'read_mesh',
         'read_journal', 'start_journal', 'stop_journal', 'replace_mesh',
         'write', 'read_settings', 'read_field_functions', 'read_injections',
         'read_profile', 'read_pdf', 'read_isat_table', 'show_configuration',
         'stop_macro', 'start_transcript', 'stop_transcript',
         'data_file_options']

    _child_classes = dict(
        single_precision_coordinates=single_precision_coordinates_cls,
        binary_legacy_files=binary_legacy_files_cls,
        cff_files=cff_files_cls,
        convert_hanging_nodes_during_read=convert_hanging_nodes_during_read_cls,
        async_optimize=async_optimize_cls,
        write_pdat=write_pdat_cls,
        confirm_overwrite=confirm_overwrite_cls,
        auto_save=auto_save_cls,
        export=export_cls,
        import_=import__cls,
        parametric_project=parametric_project_cls,
        cffio_options=cffio_options_cls,
        define_macro=define_macro_cls,
        execute_macro=execute_macro_cls,
        read_macros=read_macros_cls,
        read=read_cls,
        read_case=read_case_cls,
        read_case_data=read_case_data_cls,
        read_case_setting=read_case_setting_cls,
        read_data=read_data_cls,
        read_mesh=read_mesh_cls,
        read_journal=read_journal_cls,
        start_journal=start_journal_cls,
        stop_journal=stop_journal_cls,
        replace_mesh=replace_mesh_cls,
        write=write_cls,
        read_settings=read_settings_cls,
        read_field_functions=read_field_functions_cls,
        read_injections=read_injections_cls,
        read_profile=read_profile_cls,
        read_pdf=read_pdf_cls,
        read_isat_table=read_isat_table_cls,
        show_configuration=show_configuration_cls,
        stop_macro=stop_macro_cls,
        start_transcript=start_transcript_cls,
        stop_transcript=stop_transcript_cls,
        data_file_options=data_file_options_cls,
    )

    return_type = "<object object at 0x7fb6784db300>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .scheme import scheme as scheme_cls
from .low_order_scheme import low_order_scheme as low_order_scheme_cls
from .high_order_scheme import high_order_scheme as high_order_scheme_cls
from .accuracy_control import accuracy_control as accuracy_control_cls

class tracking(Group):
    """
    'tracking' child.
    """

    fluent_name = "tracking"

    child_names = \
        ['scheme', 'low_order_scheme', 'high_order_scheme',
         'accuracy_control']

    _child_classes = dict(
        scheme=scheme_cls,
        low_order_scheme=low_order_scheme_cls,
        high_order_scheme=high_order_scheme_cls,
        accuracy_control=accuracy_control_cls,
    )

    return_type = "<object object at 0x7fc5c18a5f40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .dolly import dolly as dolly_cls
from .field_1 import field as field_cls
from .orbit import orbit as orbit_cls
from .pan import pan as pan_cls
from .position_1 import position as position_cls
from .projection import projection as projection_cls
from .roll import roll as roll_cls
from .target_1 import target as target_cls
from .up_vector import up_vector as up_vector_cls
from .zoom import zoom as zoom_cls

class camera(Group):
    fluent_name = ...
    command_names = ...

    def dolly(self, right: Union[float, str], up: Union[float, str], in_: Union[float, str]):
        """
        Adjust the camera position and target.
        
        Parameters
        ----------
            right : real
                'right' child.
            up : real
                'up' child.
            in_ : real
                'in' child.
        
        """

    def field(self, width: Union[float, str], height: Union[float, str]):
        """
        Set the field of view (width and height).
        
        Parameters
        ----------
            width : real
                'width' child.
            height : real
                'height' child.
        
        """

    def orbit(self, right: Union[float, str], up: Union[float, str]):
        """
        Adjust the camera position without modifying the target.
        
        Parameters
        ----------
            right : real
                'right' child.
            up : real
                'up' child.
        
        """

    def pan(self, right: Union[float, str], up: Union[float, str]):
        """
        Adjust the camera position without modifying the position.
        
        Parameters
        ----------
            right : real
                'right' child.
            up : real
                'up' child.
        
        """

    def position(self, xyz: List[Union[float, str]]):
        """
        Set the camera position.
        
        Parameters
        ----------
            xyz : List
                'xyz' child.
        
        """

    def projection(self, type: str):
        """
        Set the camera projection.
        
        Parameters
        ----------
            type : str
                'type' child.
        
        """

    def roll(self, counter_clockwise: Union[float, str]):
        """
        Adjust the camera up-vector.
        
        Parameters
        ----------
            counter_clockwise : real
                'counter_clockwise' child.
        
        """

    def target(self, xyz: List[Union[float, str]]):
        """
        Set the point to be the center of the camera view.
        
        Parameters
        ----------
            xyz : List
                'xyz' child.
        
        """

    def up_vector(self, xyz: List[Union[float, str]]):
        """
        Set the camera up-vector.
        
        Parameters
        ----------
            xyz : List
                'xyz' child.
        
        """

    def zoom(self, factor: Union[float, str]):
        """
        Adjust the camera field of view.
        
        Parameters
        ----------
            factor : real
                'factor' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .adapt import adapt as adapt_cls
from .anisotropic_adaption import anisotropic_adaption as anisotropic_adaption_cls
from .check_before_solve import check_before_solve as check_before_solve_cls
from .check_verbosity import check_verbosity as check_verbosity_cls
from .enhanced_orthogonal_quality import enhanced_orthogonal_quality as enhanced_orthogonal_quality_cls
from .matching_tolerance import matching_tolerance as matching_tolerance_cls
from .show_periodic_shadow_zones import show_periodic_shadow_zones as show_periodic_shadow_zones_cls
from .reorder import reorder as reorder_cls
from .repair_improve import repair_improve as repair_improve_cls
from .surface_mesh import surface_mesh as surface_mesh_cls
from .polyhedra import polyhedra as polyhedra_cls
from .wall_distance_method import wall_distance_method as wall_distance_method_cls
from .adjacency import adjacency as adjacency_cls
from .check import check as check_cls
from .memory_usage import memory_usage as memory_usage_cls
from .mesh_info import mesh_info as mesh_info_cls
from .quality import quality as quality_cls
from .rotate import rotate as rotate_cls
from .scale import scale as scale_cls
from .size_info import size_info as size_info_cls
from .redistribute_boundary_layer import redistribute_boundary_layer as redistribute_boundary_layer_cls
from .swap_mesh_faces import swap_mesh_faces as swap_mesh_faces_cls
from .smooth_mesh import smooth_mesh as smooth_mesh_cls
from .replace import replace as replace_cls
from .translate import translate as translate_cls

class mesh(Group):
    fluent_name = ...
    child_names = ...
    adapt: adapt_cls = ...
    anisotropic_adaption: anisotropic_adaption_cls = ...
    check_before_solve: check_before_solve_cls = ...
    check_verbosity: check_verbosity_cls = ...
    enhanced_orthogonal_quality: enhanced_orthogonal_quality_cls = ...
    matching_tolerance: matching_tolerance_cls = ...
    show_periodic_shadow_zones: show_periodic_shadow_zones_cls = ...
    reorder: reorder_cls = ...
    repair_improve: repair_improve_cls = ...
    surface_mesh: surface_mesh_cls = ...
    polyhedra: polyhedra_cls = ...
    wall_distance_method: wall_distance_method_cls = ...
    command_names = ...

    def adjacency(self, ):
        """
        View and rename face zones adjacent to selected cell zones.
        """

    def check(self, ):
        """
        Perform various mesh consistency checks.
        """

    def memory_usage(self, ):
        """
        Report solver memory use.
        """

    def mesh_info(self, print_level: int):
        """
        Print zone information size.
        
        Parameters
        ----------
            print_level : int
                Print zone information size.
        
        """

    def quality(self, ):
        """
        Perform analysis of mesh quality.
        """

    def rotate(self, angle: Union[float, str], origin: List[Union[float, str]], axis_components: List[Union[float, str]]):
        """
        Rotate the mesh.
        
        Parameters
        ----------
            angle : real
                'angle' child.
            origin : List
                'origin' child.
            axis_components : List
                'axis_components' child.
        
        """

    def scale(self, x_scale: Union[float, str], y_scale: Union[float, str], z_scale: Union[float, str]):
        """
        'scale' command.
        
        Parameters
        ----------
            x_scale : real
                'x_scale' child.
            y_scale : real
                'y_scale' child.
            z_scale : real
                'z_scale' child.
        
        """

    def size_info(self, ):
        """
        Print mesh size.
        """

    def redistribute_boundary_layer(self, thread_id: int, growth_rate: Union[float, str]):
        """
        Enforce growth rate in boundary layer.
        
        Parameters
        ----------
            thread_id : int
                'thread_id' child.
            growth_rate : real
                'growth_rate' child.
        
        """

    def swap_mesh_faces(self, ):
        """
        Swap mesh faces.
        """

    def smooth_mesh(self, type_of_smoothing: str, number_of_iterations: int, relaxtion_factor: Union[float, str], percentage_of_cells: Union[float, str], skewness_threshold: Union[float, str]):
        """
        Smooth the mesh using quality-based, Laplace or skewness methods.
        
        Parameters
        ----------
            type_of_smoothing : str
                'type_of_smoothing' child.
            number_of_iterations : int
                'number_of_iterations' child.
            relaxtion_factor : real
                'relaxtion_factor' child.
            percentage_of_cells : real
                'percentage_of_cells' child.
            skewness_threshold : real
                'skewness_threshold' child.
        
        """

    def replace(self, name: str, zones: bool):
        """
        Replace mesh and interpolate data.
        
        Parameters
        ----------
            name : str
                'name' child.
            zones : bool
                'zones' child.
        
        """

    def translate(self, offset: List[Union[float, str]]):
        """
        Translate the mesh.
        
        Parameters
        ----------
            offset : List
                'offset' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .local_dt import local_dt as local_dt_cls
from .global_dt import global_dt as global_dt_cls

class pseudo_time_method_usage(Group):
    fluent_name = ...
    child_names = ...
    local_dt: local_dt_cls = ...
    global_dt: global_dt_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .visible import visible as visible_cls
from .size import size as size_cls
from .color import color as color_cls
from .log_scale import log_scale as log_scale_cls
from .format import format as format_cls
from .user_skip import user_skip as user_skip_cls
from .show_all import show_all as show_all_cls
from .position import position as position_cls
from .font_name import font_name as font_name_cls
from .font_automatic import font_automatic as font_automatic_cls
from .font_size import font_size as font_size_cls
from .length_1 import length as length_cls
from .width import width as width_cls

class color_map(Group):
    fluent_name = ...
    child_names = ...
    visible: visible_cls = ...
    size: size_cls = ...
    color: color_cls = ...
    log_scale: log_scale_cls = ...
    format: format_cls = ...
    user_skip: user_skip_cls = ...
    show_all: show_all_cls = ...
    position: position_cls = ...
    font_name: font_name_cls = ...
    font_automatic: font_automatic_cls = ...
    font_size: font_size_cls = ...
    length: length_cls = ...
    width: width_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .type_2 import type as type_cls
from .formula import formula as formula_cls

class copy_by_formula(Command):
    """
    Copy a material from the database (pick by formula).
    
    Parameters
    ----------
        type : str
            'type' child.
        formula : str
            'formula' child.
    
    """

    fluent_name = "copy-by-formula"

    argument_names = \
        ['type', 'formula']

    _child_classes = dict(
        type=type_cls,
        formula=formula_cls,
    )

    return_type = "<object object at 0x7fb66c2e2150>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .b import b as b_cls
from .reference_viscosity import reference_viscosity as reference_viscosity_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .temperature_exponent import temperature_exponent as temperature_exponent_cls

class power_law(Group):
    """
    'power_law' child.
    """

    fluent_name = "power-law"

    child_names = \
        ['option', 'b', 'reference_viscosity', 'reference_temperature',
         'temperature_exponent']

    _child_classes = dict(
        option=option_cls,
        b=b_cls,
        reference_viscosity=reference_viscosity_cls,
        reference_temperature=reference_temperature_cls,
        temperature_exponent=temperature_exponent_cls,
    )

    return_type = "<object object at 0x7fc5785e8510>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .multi_grid_controls_child import multi_grid_controls_child


class multi_grid_controls(NamedObject[multi_grid_controls_child], CreatableNamedObjectMixinOld[multi_grid_controls_child]):
    """
    'multi_grid_controls' child.
    """

    fluent_name = "multi-grid-controls"

    child_object_type: multi_grid_controls_child = multi_grid_controls_child
    """
    child_object_type of multi_grid_controls.
    """
    return_type = "<object object at 0x7fd82ae38470>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .all_1 import all as all_cls
from .one_to_one_pairing import one_to_one_pairing as one_to_one_pairing_cls
from .new_si_id import new_si_id as new_si_id_cls
from .si_create import si_create as si_create_cls
from .si_name import si_name as si_name_cls
from .apply_mapped import apply_mapped as apply_mapped_cls
from .static_interface import static_interface as static_interface_cls

class auto_pairing(Command):
    fluent_name = ...
    argument_names = ...
    all: all_cls = ...
    one_to_one_pairing: one_to_one_pairing_cls = ...
    new_si_id: new_si_id_cls = ...
    si_create: si_create_cls = ...
    si_name: si_name_cls = ...
    apply_mapped: apply_mapped_cls = ...
    static_interface: static_interface_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .motion import motion as motion_cls
from .parent_1 import parent_1 as parent_1_cls
from .initial_state import initial_state as initial_state_cls
from .display_state import display_state as display_state_cls

class reference_frames_child(Group):
    fluent_name = ...
    child_names = ...
    motion: motion_cls = ...
    parent_1: parent_1_cls = ...
    initial_state: initial_state_cls = ...
    display_state: display_state_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_3 import enable as enable_cls
from .beams import beams as beams_cls
from .statistics import statistics as statistics_cls
from .sampling_iterations import sampling_iterations as sampling_iterations_cls
from .index_of_refraction import index_of_refraction as index_of_refraction_cls
from .report import report as report_cls
from .verbosity_2 import verbosity as verbosity_cls

class optics(Group):
    fluent_name = ...
    child_names = ...
    enable: enable_cls = ...
    beams: beams_cls = ...
    statistics: statistics_cls = ...
    sampling_iterations: sampling_iterations_cls = ...
    index_of_refraction: index_of_refraction_cls = ...
    report: report_cls = ...
    verbosity: verbosity_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .file_name_1 import file_name as file_name_cls
from .cell_func_domain_export import cell_func_domain_export as cell_func_domain_export_cls

class avs(Command):
    """
    Write an AVS UCD file.
    
    Parameters
    ----------
        file_name : str
            'file_name' child.
        cell_func_domain_export : List
            'cell_func_domain_export' child.
    
    """

    fluent_name = "avs"

    argument_names = \
        ['file_name', 'cell_func_domain_export']

    _child_classes = dict(
        file_name=file_name_cls,
        cell_func_domain_export=cell_func_domain_export_cls,
    )

    return_type = "<object object at 0x7f76ed1ea860>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class time_scale_modification_method(Integer):
    """
    Set time scale modification method [0-time-step, 1-cfl].
    """

    fluent_name = "time-scale-modification-method"

    return_type = "<object object at 0x7fd82ae38ad0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .use_inherent_material_color_1 import use_inherent_material_color as use_inherent_material_color_cls
from .reset import reset as reset_cls
from .list_surfaces_by_color import list_surfaces_by_color as list_surfaces_by_color_cls
from .list_surfaces_by_material import list_surfaces_by_material as list_surfaces_by_material_cls

class by_surface(Group):
    fluent_name = ...
    child_names = ...
    use_inherent_material_color: use_inherent_material_color_cls = ...
    command_names = ...

    def reset(self, reset_color: bool):
        """
        To reset colors and/or materials to the defaults.
        
        Parameters
        ----------
            reset_color : bool
                'reset_color' child.
        
        """

    def list_surfaces_by_color(self, ):
        """
        To list the surfaces by its color.
        """

    def list_surfaces_by_material(self, ):
        """
        To list the surfaces by its material.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .child_object_type_child import child_object_type_child


class flux_momentum_components(ListObject[child_object_type_child]):
    """
    'flux_momentum_components' child.
    """

    fluent_name = "flux-momentum-components"

    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of flux_momentum_components.
    """
    return_type = "<object object at 0x7fd82b06f9f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .two_stage import two_stage as two_stage_cls
from .default_multi_stage import default_multi_stage as default_multi_stage_cls

class runge_kutta(Group):
    """
    'runge_kutta' child.
    """

    fluent_name = "runge-kutta"

    child_names = \
        ['two_stage', 'default_multi_stage']

    _child_classes = dict(
        two_stage=two_stage_cls,
        default_multi_stage=default_multi_stage_cls,
    )

    return_type = "<object object at 0x7fc55434f190>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .border_1 import border as border_cls
from .bottom_1 import bottom as bottom_cls
from .left_1 import left as left_cls
from .right_2 import right as right_cls
from .top_1 import top as top_cls
from .visible_2 import visible as visible_cls

class main(Group):
    """
    Enter the main view window options menu.
    """

    fluent_name = "main"

    child_names = \
        ['border', 'bottom', 'left', 'right', 'top', 'visible']

    _child_classes = dict(
        border=border_cls,
        bottom=bottom_cls,
        left=left_cls,
        right=right_cls,
        top=top_cls,
        visible=visible_cls,
    )

    return_type = "<object object at 0x7fb5f5f71020>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .general_settings import general_settings as general_settings_cls
from .injections import injections as injections_cls
from .numerics import numerics as numerics_cls
from .parallel import parallel as parallel_cls
from .physical_models_1 import physical_models as physical_models_cls
from .tracking_1 import tracking as tracking_cls
from .user_defined_functions import user_defined_functions as user_defined_functions_cls

class discrete_phase(Group):
    """
    Toplevel menu of the Discrete Phase multiphase model. A discrete phase model (DPM) is used when the aim is to investigate the behavior of the particles from a Lagrangian view and a discrete perspective.
    """

    fluent_name = "discrete-phase"

    child_names = \
        ['general_settings', 'injections', 'numerics', 'parallel',
         'physical_models', 'tracking', 'user_defined_functions']

    _child_classes = dict(
        general_settings=general_settings_cls,
        injections=injections_cls,
        numerics=numerics_cls,
        parallel=parallel_cls,
        physical_models=physical_models_cls,
        tracking=tracking_cls,
        user_defined_functions=user_defined_functions_cls,
    )

    return_type = "<object object at 0x7fb66c2e1910>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .use_weighting import use_weighting as use_weighting_cls
from .make_steady_from_unsteady_file import make_steady_from_unsteady_file as make_steady_from_unsteady_file_cls
from .weighting_variable import weighting_variable as weighting_variable_cls
from .reset_min_and_max import reset_min_and_max as reset_min_and_max_cls
from .set_minimum import set_minimum as set_minimum_cls
from .set_maximum import set_maximum as set_maximum_cls
from .use_logarithmic import use_logarithmic as use_logarithmic_cls
from .number_of_bins import number_of_bins as number_of_bins_cls
from .all_variables_number_of_bins import all_variables_number_of_bins as all_variables_number_of_bins_cls
from .list_settings import list_settings as list_settings_cls

class setup_reduction(Group):
    """
    Set up the sample data reduction by specifying all relevant options and setting parameters as desired.
    """

    fluent_name = "setup-reduction"

    child_names = \
        ['use_weighting', 'make_steady_from_unsteady_file']

    command_names = \
        ['weighting_variable', 'reset_min_and_max', 'set_minimum',
         'set_maximum', 'use_logarithmic', 'number_of_bins',
         'all_variables_number_of_bins', 'list_settings']

    _child_classes = dict(
        use_weighting=use_weighting_cls,
        make_steady_from_unsteady_file=make_steady_from_unsteady_file_cls,
        weighting_variable=weighting_variable_cls,
        reset_min_and_max=reset_min_and_max_cls,
        set_minimum=set_minimum_cls,
        set_maximum=set_maximum_cls,
        use_logarithmic=use_logarithmic_cls,
        number_of_bins=number_of_bins_cls,
        all_variables_number_of_bins=all_variables_number_of_bins_cls,
        list_settings=list_settings_cls,
    )

    return_type = "<object object at 0x7fb5f5f725e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .source_terms_child import source_terms_child


class source_terms(NamedObject[source_terms_child], _NonCreatableNamedObjectMixin[source_terms_child]):
    """
    'source_terms' child.
    """

    fluent_name = "source-terms"

    child_object_type: source_terms_child = source_terms_child
    """
    child_object_type of source_terms.
    """
    return_type = "<object object at 0x7fc554ed4ef0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .convective_heat_transfer import convective_heat_transfer as convective_heat_transfer_cls
from .include_convective_heat_transfer import include_convective_heat_transfer as include_convective_heat_transfer_cls
from .film_movement import film_movement as film_movement_cls
from .lwf_particle_inclusion_in_dpm_concentration_enabled import lwf_particle_inclusion_in_dpm_concentration_enabled as lwf_particle_inclusion_in_dpm_concentration_enabled_cls
from .wall_film_temperature_limiter import wall_film_temperature_limiter as wall_film_temperature_limiter_cls

class wall_film(Group):
    fluent_name = ...
    child_names = ...
    convective_heat_transfer: convective_heat_transfer_cls = ...
    include_convective_heat_transfer: include_convective_heat_transfer_cls = ...
    film_movement: film_movement_cls = ...
    lwf_particle_inclusion_in_dpm_concentration_enabled: lwf_particle_inclusion_in_dpm_concentration_enabled_cls = ...
    wall_film_temperature_limiter: wall_film_temperature_limiter_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .nist_fluid import nist_fluid as nist_fluid_cls
from .lookup_table import lookup_table as lookup_table_cls
from .pressure_points import pressure_points as pressure_points_cls
from .pressure_minimum import pressure_minimum as pressure_minimum_cls
from .pressure_maximum import pressure_maximum as pressure_maximum_cls
from .temperature_points import temperature_points as temperature_points_cls
from .temperature_minimum import temperature_minimum as temperature_minimum_cls
from .temperature_maximum import temperature_maximum as temperature_maximum_cls
from .saturation_points import saturation_points as saturation_points_cls

class real_gas_nist(Group):
    fluent_name = ...
    child_names = ...
    nist_fluid: nist_fluid_cls = ...
    lookup_table: lookup_table_cls = ...
    pressure_points: pressure_points_cls = ...
    pressure_minimum: pressure_minimum_cls = ...
    pressure_maximum: pressure_maximum_cls = ...
    temperature_points: temperature_points_cls = ...
    temperature_minimum: temperature_minimum_cls = ...
    temperature_maximum: temperature_maximum_cls = ...
    saturation_points: saturation_points_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .equation_for_residual import equation_for_residual as equation_for_residual_cls
from .threshold import threshold as threshold_cls

class residual(Group):
    fluent_name = ...
    child_names = ...
    equation_for_residual: equation_for_residual_cls = ...
    threshold: threshold_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_1 import name as name_cls
from .uid import uid as uid_cls
from .options_7 import options as options_cls
from .filter_settings import filter_settings as filter_settings_cls
from .range import range as range_cls
from .style_attribute_1 import style_attribute as style_attribute_cls
from .vector_settings import vector_settings as vector_settings_cls
from .plot_1 import plot as plot_cls
from .track_single_particle_stream import track_single_particle_stream as track_single_particle_stream_cls
from .skip import skip as skip_cls
from .coarsen import coarsen as coarsen_cls
from .field import field as field_cls
from .injections_list import injections_list as injections_list_cls
from .free_stream_particles import free_stream_particles as free_stream_particles_cls
from .wall_film_particles import wall_film_particles as wall_film_particles_cls
from .track_pdf_particles import track_pdf_particles as track_pdf_particles_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .axes import axes as axes_cls
from .curves import curves as curves_cls
from .display_2 import display as display_cls

class particle_track_child(Group):
    """
    'child_object_type' of particle_track.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'filter_settings', 'range',
         'style_attribute', 'vector_settings', 'plot',
         'track_single_particle_stream', 'skip', 'coarsen', 'field',
         'injections_list', 'free_stream_particles', 'wall_film_particles',
         'track_pdf_particles', 'color_map', 'draw_mesh', 'mesh_object',
         'display_state_name', 'axes', 'curves']

    command_names = \
        ['display']

    _child_classes = dict(
        name=name_cls,
        uid=uid_cls,
        options=options_cls,
        filter_settings=filter_settings_cls,
        range=range_cls,
        style_attribute=style_attribute_cls,
        vector_settings=vector_settings_cls,
        plot=plot_cls,
        track_single_particle_stream=track_single_particle_stream_cls,
        skip=skip_cls,
        coarsen=coarsen_cls,
        field=field_cls,
        injections_list=injections_list_cls,
        free_stream_particles=free_stream_particles_cls,
        wall_film_particles=wall_film_particles_cls,
        track_pdf_particles=track_pdf_particles_cls,
        color_map=color_map_cls,
        draw_mesh=draw_mesh_cls,
        mesh_object=mesh_object_cls,
        display_state_name=display_state_name_cls,
        axes=axes_cls,
        curves=curves_cls,
        display=display_cls,
    )

    return_type = "<object object at 0x7fc55413d360>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .geometry_1 import geometry as geometry_cls
from .physics import physics as physics_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .scaled import scaled as scaled_cls
from .report_type import report_type as report_type_cls
from .average_over import average_over as average_over_cls
from .per_zone import per_zone as per_zone_cls
from .thread_names import thread_names as thread_names_cls
from .thread_ids import thread_ids as thread_ids_cls
from .old_props import old_props as old_props_cls
from .reference_frame import reference_frame as reference_frame_cls
from .force_vector import force_vector as force_vector_cls

class lift_child(Group):
    fluent_name = ...
    child_names = ...
    geometry: geometry_cls = ...
    physics: physics_cls = ...
    retain_instantaneous_values: retain_instantaneous_values_cls = ...
    scaled: scaled_cls = ...
    report_type: report_type_cls = ...
    average_over: average_over_cls = ...
    per_zone: per_zone_cls = ...
    thread_names: thread_names_cls = ...
    thread_ids: thread_ids_cls = ...
    old_props: old_props_cls = ...
    reference_frame: reference_frame_cls = ...
    force_vector: force_vector_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .phase import phase as phase_cls
from .material import material as material_cls
from .sources import sources as sources_cls
from .source_terms import source_terms as source_terms_cls
from .fixed import fixed as fixed_cls
from .cylindrical_fixed_var import cylindrical_fixed_var as cylindrical_fixed_var_cls
from .fixes import fixes as fixes_cls
from .motion_spec import motion_spec as motion_spec_cls
from .relative_to_thread import relative_to_thread as relative_to_thread_cls
from .omega import omega as omega_cls
from .axis_origin_component import axis_origin_component as axis_origin_component_cls
from .axis_direction_component import axis_direction_component as axis_direction_component_cls
from .udf_zmotion_name import udf_zmotion_name as udf_zmotion_name_cls
from .mrf_motion import mrf_motion as mrf_motion_cls
from .mrf_relative_to_thread import mrf_relative_to_thread as mrf_relative_to_thread_cls
from .mrf_omega import mrf_omega as mrf_omega_cls
from .reference_frame_velocity_components import reference_frame_velocity_components as reference_frame_velocity_components_cls
from .reference_frame_axis_origin_components import reference_frame_axis_origin_components as reference_frame_axis_origin_components_cls
from .reference_frame_axis_direction_components import reference_frame_axis_direction_components as reference_frame_axis_direction_components_cls
from .mrf_udf_zmotion_name import mrf_udf_zmotion_name as mrf_udf_zmotion_name_cls
from .mgrid_enable_transient import mgrid_enable_transient as mgrid_enable_transient_cls
from .mgrid_motion import mgrid_motion as mgrid_motion_cls
from .mgrid_relative_to_thread import mgrid_relative_to_thread as mgrid_relative_to_thread_cls
from .mgrid_omega import mgrid_omega as mgrid_omega_cls
from .moving_mesh_velocity_components import moving_mesh_velocity_components as moving_mesh_velocity_components_cls
from .moving_mesh_axis_origin_components import moving_mesh_axis_origin_components as moving_mesh_axis_origin_components_cls
from .mgrid_udf_zmotion_name import mgrid_udf_zmotion_name as mgrid_udf_zmotion_name_cls
from .solid_motion import solid_motion as solid_motion_cls
from .solid_relative_to_thread import solid_relative_to_thread as solid_relative_to_thread_cls
from .solid_omega import solid_omega as solid_omega_cls
from .solid_motion_velocity_components import solid_motion_velocity_components as solid_motion_velocity_components_cls
from .solid_motion_axis_origin_components import solid_motion_axis_origin_components as solid_motion_axis_origin_components_cls
from .solid_motion_axis_direction_components import solid_motion_axis_direction_components as solid_motion_axis_direction_components_cls
from .solid_udf_zmotion_name import solid_udf_zmotion_name as solid_udf_zmotion_name_cls
from .radiating import radiating as radiating_cls
from .les_embedded import les_embedded as les_embedded_cls
from .contact_property import contact_property as contact_property_cls
from .vapor_phase_realgas import vapor_phase_realgas as vapor_phase_realgas_cls
from .laminar import laminar as laminar_cls
from .laminar_mut_zero import laminar_mut_zero as laminar_mut_zero_cls
from .les_embedded_spec import les_embedded_spec as les_embedded_spec_cls
from .les_embedded_mom_scheme import les_embedded_mom_scheme as les_embedded_mom_scheme_cls
from .les_embedded_c_wale import les_embedded_c_wale as les_embedded_c_wale_cls
from .les_embedded_c_smag import les_embedded_c_smag as les_embedded_c_smag_cls
from .glass import glass as glass_cls
from .porous import porous as porous_cls
from .conical import conical as conical_cls
from .dir_spec_cond import dir_spec_cond as dir_spec_cond_cls
from .cursys import cursys as cursys_cls
from .cursys_name import cursys_name as cursys_name_cls
from .direction_1_x import direction_1_x as direction_1_x_cls
from .direction_1_y import direction_1_y as direction_1_y_cls
from .direction_1_z import direction_1_z as direction_1_z_cls
from .direction_2_x import direction_2_x as direction_2_x_cls
from .direction_2_y import direction_2_y as direction_2_y_cls
from .direction_2_z import direction_2_z as direction_2_z_cls
from .cone_axis_x import cone_axis_x as cone_axis_x_cls
from .cone_axis_y import cone_axis_y as cone_axis_y_cls
from .cone_axis_z import cone_axis_z as cone_axis_z_cls
from .cone_axis_pt_x import cone_axis_pt_x as cone_axis_pt_x_cls
from .cone_axis_pt_y import cone_axis_pt_y as cone_axis_pt_y_cls
from .cone_axis_pt_z import cone_axis_pt_z as cone_axis_pt_z_cls
from .cone_angle import cone_angle as cone_angle_cls
from .rel_vel_resistance import rel_vel_resistance as rel_vel_resistance_cls
from .porous_r_1 import porous_r_1 as porous_r_1_cls
from .porous_r_2 import porous_r_2 as porous_r_2_cls
from .porous_r_3 import porous_r_3 as porous_r_3_cls
from .alt_inertial_form import alt_inertial_form as alt_inertial_form_cls
from .porous_c_1 import porous_c_1 as porous_c_1_cls
from .porous_c_2 import porous_c_2 as porous_c_2_cls
from .porous_c_3 import porous_c_3 as porous_c_3_cls
from .c0 import c0 as c0_cls
from .c1 import c1 as c1_cls
from .porosity import porosity as porosity_cls
from .viscosity_ratio import viscosity_ratio as viscosity_ratio_cls
from .none import none as none_cls
from .corey import corey as corey_cls
from .stone_1 import stone_1 as stone_1_cls
from .stone_2 import stone_2 as stone_2_cls
from .rel_perm_limit_p1 import rel_perm_limit_p1 as rel_perm_limit_p1_cls
from .rel_perm_limit_p2 import rel_perm_limit_p2 as rel_perm_limit_p2_cls
from .ref_perm_p1 import ref_perm_p1 as ref_perm_p1_cls
from .exp_p1 import exp_p1 as exp_p1_cls
from .res_sat_p1 import res_sat_p1 as res_sat_p1_cls
from .ref_perm_p2 import ref_perm_p2 as ref_perm_p2_cls
from .exp_p2 import exp_p2 as exp_p2_cls
from .res_sat_p2 import res_sat_p2 as res_sat_p2_cls
from .ref_perm_p3 import ref_perm_p3 as ref_perm_p3_cls
from .exp_p3 import exp_p3 as exp_p3_cls
from .res_sat_p3 import res_sat_p3 as res_sat_p3_cls
from .capillary_pressure import capillary_pressure as capillary_pressure_cls
from .max_capillary_pressure import max_capillary_pressure as max_capillary_pressure_cls
from .van_genuchten_pg import van_genuchten_pg as van_genuchten_pg_cls
from .van_genuchten_ng import van_genuchten_ng as van_genuchten_ng_cls
from .skjaeveland_nw_pc_coef import skjaeveland_nw_pc_coef as skjaeveland_nw_pc_coef_cls
from .skjaeveland_nw_pc_pwr import skjaeveland_nw_pc_pwr as skjaeveland_nw_pc_pwr_cls
from .skjaeveland_wet_pc_coef import skjaeveland_wet_pc_coef as skjaeveland_wet_pc_coef_cls
from .skjaeveland_wet_pc_pwr import skjaeveland_wet_pc_pwr as skjaeveland_wet_pc_pwr_cls
from .brooks_corey_pe import brooks_corey_pe as brooks_corey_pe_cls
from .brooks_corey_ng import brooks_corey_ng as brooks_corey_ng_cls
from .leverett_con_ang import leverett_con_ang as leverett_con_ang_cls
from .rp_cbox_p1 import rp_cbox_p1 as rp_cbox_p1_cls
from .rp_edit_p1 import rp_edit_p1 as rp_edit_p1_cls
from .rel_perm_tabular_p1 import rel_perm_tabular_p1 as rel_perm_tabular_p1_cls
from .rel_perm_table_p1 import rel_perm_table_p1 as rel_perm_table_p1_cls
from .rel_perm_satw_p1 import rel_perm_satw_p1 as rel_perm_satw_p1_cls
from .rel_perm_rp_p1 import rel_perm_rp_p1 as rel_perm_rp_p1_cls
from .rp_cbox_p2 import rp_cbox_p2 as rp_cbox_p2_cls
from .rp_edit_p2 import rp_edit_p2 as rp_edit_p2_cls
from .rel_perm_tabular_p2 import rel_perm_tabular_p2 as rel_perm_tabular_p2_cls
from .rel_perm_table_p2 import rel_perm_table_p2 as rel_perm_table_p2_cls
from .rel_perm_satw_p2 import rel_perm_satw_p2 as rel_perm_satw_p2_cls
from .rel_perm_rp_p2 import rel_perm_rp_p2 as rel_perm_rp_p2_cls
from .wetting_phase import wetting_phase as wetting_phase_cls
from .non_wetting_phase import non_wetting_phase as non_wetting_phase_cls
from .equib_thermal import equib_thermal as equib_thermal_cls
from .non_equib_thermal import non_equib_thermal as non_equib_thermal_cls
from .solid_material import solid_material as solid_material_cls
from .area_density import area_density as area_density_cls
from .heat_transfer_coeff import heat_transfer_coeff as heat_transfer_coeff_cls
from .fanzone import fanzone as fanzone_cls
from .fan_zone_list import fan_zone_list as fan_zone_list_cls
from .fan_thickness import fan_thickness as fan_thickness_cls
from .fan_hub_rad import fan_hub_rad as fan_hub_rad_cls
from .fan_tip_rad import fan_tip_rad as fan_tip_rad_cls
from .fan_x_origin import fan_x_origin as fan_x_origin_cls
from .fan_y_origin import fan_y_origin as fan_y_origin_cls
from .fan_z_origin import fan_z_origin as fan_z_origin_cls
from .fan_rot_dir import fan_rot_dir as fan_rot_dir_cls
from .fan_opert_angvel import fan_opert_angvel as fan_opert_angvel_cls
from .fan_inflection_point import fan_inflection_point as fan_inflection_point_cls
from .limit_flow_fan import limit_flow_fan as limit_flow_fan_cls
from .max_flow_rate import max_flow_rate as max_flow_rate_cls
from .min_flow_rate import min_flow_rate as min_flow_rate_cls
from .tan_source_term import tan_source_term as tan_source_term_cls
from .rad_source_term import rad_source_term as rad_source_term_cls
from .axial_source_term import axial_source_term as axial_source_term_cls
from .fan_axial_source_method import fan_axial_source_method as fan_axial_source_method_cls
from .fan_pre_jump import fan_pre_jump as fan_pre_jump_cls
from .fan_curve_fit import fan_curve_fit as fan_curve_fit_cls
from .fan_poly_order import fan_poly_order as fan_poly_order_cls
from .fan_ini_flow import fan_ini_flow as fan_ini_flow_cls
from .fan_test_angvel import fan_test_angvel as fan_test_angvel_cls
from .fan_test_temp import fan_test_temp as fan_test_temp_cls
from .read_fan_curve import read_fan_curve as read_fan_curve_cls
from .reaction_mechs_1 import reaction_mechs as reaction_mechs_cls
from .react import react as react_cls
from .surface_volume_ratio import surface_volume_ratio as surface_volume_ratio_cls
from .electrolyte import electrolyte as electrolyte_cls
from .mp_compressive_beta_max import mp_compressive_beta_max as mp_compressive_beta_max_cls
from .mp_boiling_zone import mp_boiling_zone as mp_boiling_zone_cls
from .numerical_beach import numerical_beach as numerical_beach_cls
from .beach_id import beach_id as beach_id_cls
from .beach_multi_dir import beach_multi_dir as beach_multi_dir_cls
from .beach_damp_type import beach_damp_type as beach_damp_type_cls
from .beach_inlet_bndr import beach_inlet_bndr as beach_inlet_bndr_cls
from .beach_fs_level import beach_fs_level as beach_fs_level_cls
from .beach_bottom_level import beach_bottom_level as beach_bottom_level_cls
from .beach_dir_ni import beach_dir_ni as beach_dir_ni_cls
from .beach_dir_nj import beach_dir_nj as beach_dir_nj_cls
from .beach_dir_nk import beach_dir_nk as beach_dir_nk_cls
from .beach_damp_len_spec import beach_damp_len_spec as beach_damp_len_spec_cls
from .beach_wave_len import beach_wave_len as beach_wave_len_cls
from .beach_len_factor import beach_len_factor as beach_len_factor_cls
from .beach_start_point import beach_start_point as beach_start_point_cls
from .beach_end_point import beach_end_point as beach_end_point_cls
from .beach_dir_list import beach_dir_list as beach_dir_list_cls
from .beach_damp_relative import beach_damp_relative as beach_damp_relative_cls
from .beach_damp_resist_lin import beach_damp_resist_lin as beach_damp_resist_lin_cls
from .beach_damp_resist import beach_damp_resist as beach_damp_resist_cls
from .porous_structure import porous_structure as porous_structure_cls
from .structure_material import structure_material as structure_material_cls
from .anisotropic_spe_diff import anisotropic_spe_diff as anisotropic_spe_diff_cls
from .spe_diff_xx import spe_diff_xx as spe_diff_xx_cls
from .spe_diff_xy import spe_diff_xy as spe_diff_xy_cls
from .spe_diff_xz import spe_diff_xz as spe_diff_xz_cls
from .spe_diff_yx import spe_diff_yx as spe_diff_yx_cls
from .spe_diff_yy import spe_diff_yy as spe_diff_yy_cls
from .spe_diff_yz import spe_diff_yz as spe_diff_yz_cls
from .spe_diff_zx import spe_diff_zx as spe_diff_zx_cls
from .spe_diff_zy import spe_diff_zy as spe_diff_zy_cls
from .spe_diff_zz import spe_diff_zz as spe_diff_zz_cls

class fluid_child(Group):
    """
    'child_object_type' of fluid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'material', 'sources', 'source_terms', 'fixed',
         'cylindrical_fixed_var', 'fixes', 'motion_spec',
         'relative_to_thread', 'omega', 'axis_origin_component',
         'axis_direction_component', 'udf_zmotion_name', 'mrf_motion',
         'mrf_relative_to_thread', 'mrf_omega',
         'reference_frame_velocity_components',
         'reference_frame_axis_origin_components',
         'reference_frame_axis_direction_components', 'mrf_udf_zmotion_name',
         'mgrid_enable_transient', 'mgrid_motion', 'mgrid_relative_to_thread',
         'mgrid_omega', 'moving_mesh_velocity_components',
         'moving_mesh_axis_origin_components', 'mgrid_udf_zmotion_name',
         'solid_motion', 'solid_relative_to_thread', 'solid_omega',
         'solid_motion_velocity_components',
         'solid_motion_axis_origin_components',
         'solid_motion_axis_direction_components', 'solid_udf_zmotion_name',
         'radiating', 'les_embedded', 'contact_property',
         'vapor_phase_realgas', 'laminar', 'laminar_mut_zero',
         'les_embedded_spec', 'les_embedded_mom_scheme',
         'les_embedded_c_wale', 'les_embedded_c_smag', 'glass', 'porous',
         'conical', 'dir_spec_cond', 'cursys', 'cursys_name', 'direction_1_x',
         'direction_1_y', 'direction_1_z', 'direction_2_x', 'direction_2_y',
         'direction_2_z', 'cone_axis_x', 'cone_axis_y', 'cone_axis_z',
         'cone_axis_pt_x', 'cone_axis_pt_y', 'cone_axis_pt_z', 'cone_angle',
         'rel_vel_resistance', 'porous_r_1', 'porous_r_2', 'porous_r_3',
         'alt_inertial_form', 'porous_c_1', 'porous_c_2', 'porous_c_3', 'c0',
         'c1', 'porosity', 'viscosity_ratio', 'none', 'corey', 'stone_1',
         'stone_2', 'rel_perm_limit_p1', 'rel_perm_limit_p2', 'ref_perm_p1',
         'exp_p1', 'res_sat_p1', 'ref_perm_p2', 'exp_p2', 'res_sat_p2',
         'ref_perm_p3', 'exp_p3', 'res_sat_p3', 'capillary_pressure',
         'max_capillary_pressure', 'van_genuchten_pg', 'van_genuchten_ng',
         'skjaeveland_nw_pc_coef', 'skjaeveland_nw_pc_pwr',
         'skjaeveland_wet_pc_coef', 'skjaeveland_wet_pc_pwr',
         'brooks_corey_pe', 'brooks_corey_ng', 'leverett_con_ang',
         'rp_cbox_p1', 'rp_edit_p1', 'rel_perm_tabular_p1',
         'rel_perm_table_p1', 'rel_perm_satw_p1', 'rel_perm_rp_p1',
         'rp_cbox_p2', 'rp_edit_p2', 'rel_perm_tabular_p2',
         'rel_perm_table_p2', 'rel_perm_satw_p2', 'rel_perm_rp_p2',
         'wetting_phase', 'non_wetting_phase', 'equib_thermal',
         'non_equib_thermal', 'solid_material', 'area_density',
         'heat_transfer_coeff', 'fanzone', 'fan_zone_list', 'fan_thickness',
         'fan_hub_rad', 'fan_tip_rad', 'fan_x_origin', 'fan_y_origin',
         'fan_z_origin', 'fan_rot_dir', 'fan_opert_angvel',
         'fan_inflection_point', 'limit_flow_fan', 'max_flow_rate',
         'min_flow_rate', 'tan_source_term', 'rad_source_term',
         'axial_source_term', 'fan_axial_source_method', 'fan_pre_jump',
         'fan_curve_fit', 'fan_poly_order', 'fan_ini_flow', 'fan_test_angvel',
         'fan_test_temp', 'read_fan_curve', 'reaction_mechs', 'react',
         'surface_volume_ratio', 'electrolyte', 'mp_compressive_beta_max',
         'mp_boiling_zone', 'numerical_beach', 'beach_id', 'beach_multi_dir',
         'beach_damp_type', 'beach_inlet_bndr', 'beach_fs_level',
         'beach_bottom_level', 'beach_dir_ni', 'beach_dir_nj', 'beach_dir_nk',
         'beach_damp_len_spec', 'beach_wave_len', 'beach_len_factor',
         'beach_start_point', 'beach_end_point', 'beach_dir_list',
         'beach_damp_relative', 'beach_damp_resist_lin', 'beach_damp_resist',
         'porous_structure', 'structure_material', 'anisotropic_spe_diff',
         'spe_diff_xx', 'spe_diff_xy', 'spe_diff_xz', 'spe_diff_yx',
         'spe_diff_yy', 'spe_diff_yz', 'spe_diff_zx', 'spe_diff_zy',
         'spe_diff_zz']

    _child_classes = dict(
        phase=phase_cls,
        material=material_cls,
        sources=sources_cls,
        source_terms=source_terms_cls,
        fixed=fixed_cls,
        cylindrical_fixed_var=cylindrical_fixed_var_cls,
        fixes=fixes_cls,
        motion_spec=motion_spec_cls,
        relative_to_thread=relative_to_thread_cls,
        omega=omega_cls,
        axis_origin_component=axis_origin_component_cls,
        axis_direction_component=axis_direction_component_cls,
        udf_zmotion_name=udf_zmotion_name_cls,
        mrf_motion=mrf_motion_cls,
        mrf_relative_to_thread=mrf_relative_to_thread_cls,
        mrf_omega=mrf_omega_cls,
        reference_frame_velocity_components=reference_frame_velocity_components_cls,
        reference_frame_axis_origin_components=reference_frame_axis_origin_components_cls,
        reference_frame_axis_direction_components=reference_frame_axis_direction_components_cls,
        mrf_udf_zmotion_name=mrf_udf_zmotion_name_cls,
        mgrid_enable_transient=mgrid_enable_transient_cls,
        mgrid_motion=mgrid_motion_cls,
        mgrid_relative_to_thread=mgrid_relative_to_thread_cls,
        mgrid_omega=mgrid_omega_cls,
        moving_mesh_velocity_components=moving_mesh_velocity_components_cls,
        moving_mesh_axis_origin_components=moving_mesh_axis_origin_components_cls,
        mgrid_udf_zmotion_name=mgrid_udf_zmotion_name_cls,
        solid_motion=solid_motion_cls,
        solid_relative_to_thread=solid_relative_to_thread_cls,
        solid_omega=solid_omega_cls,
        solid_motion_velocity_components=solid_motion_velocity_components_cls,
        solid_motion_axis_origin_components=solid_motion_axis_origin_components_cls,
        solid_motion_axis_direction_components=solid_motion_axis_direction_components_cls,
        solid_udf_zmotion_name=solid_udf_zmotion_name_cls,
        radiating=radiating_cls,
        les_embedded=les_embedded_cls,
        contact_property=contact_property_cls,
        vapor_phase_realgas=vapor_phase_realgas_cls,
        laminar=laminar_cls,
        laminar_mut_zero=laminar_mut_zero_cls,
        les_embedded_spec=les_embedded_spec_cls,
        les_embedded_mom_scheme=les_embedded_mom_scheme_cls,
        les_embedded_c_wale=les_embedded_c_wale_cls,
        les_embedded_c_smag=les_embedded_c_smag_cls,
        glass=glass_cls,
        porous=porous_cls,
        conical=conical_cls,
        dir_spec_cond=dir_spec_cond_cls,
        cursys=cursys_cls,
        cursys_name=cursys_name_cls,
        direction_1_x=direction_1_x_cls,
        direction_1_y=direction_1_y_cls,
        direction_1_z=direction_1_z_cls,
        direction_2_x=direction_2_x_cls,
        direction_2_y=direction_2_y_cls,
        direction_2_z=direction_2_z_cls,
        cone_axis_x=cone_axis_x_cls,
        cone_axis_y=cone_axis_y_cls,
        cone_axis_z=cone_axis_z_cls,
        cone_axis_pt_x=cone_axis_pt_x_cls,
        cone_axis_pt_y=cone_axis_pt_y_cls,
        cone_axis_pt_z=cone_axis_pt_z_cls,
        cone_angle=cone_angle_cls,
        rel_vel_resistance=rel_vel_resistance_cls,
        porous_r_1=porous_r_1_cls,
        porous_r_2=porous_r_2_cls,
        porous_r_3=porous_r_3_cls,
        alt_inertial_form=alt_inertial_form_cls,
        porous_c_1=porous_c_1_cls,
        porous_c_2=porous_c_2_cls,
        porous_c_3=porous_c_3_cls,
        c0=c0_cls,
        c1=c1_cls,
        porosity=porosity_cls,
        viscosity_ratio=viscosity_ratio_cls,
        none=none_cls,
        corey=corey_cls,
        stone_1=stone_1_cls,
        stone_2=stone_2_cls,
        rel_perm_limit_p1=rel_perm_limit_p1_cls,
        rel_perm_limit_p2=rel_perm_limit_p2_cls,
        ref_perm_p1=ref_perm_p1_cls,
        exp_p1=exp_p1_cls,
        res_sat_p1=res_sat_p1_cls,
        ref_perm_p2=ref_perm_p2_cls,
        exp_p2=exp_p2_cls,
        res_sat_p2=res_sat_p2_cls,
        ref_perm_p3=ref_perm_p3_cls,
        exp_p3=exp_p3_cls,
        res_sat_p3=res_sat_p3_cls,
        capillary_pressure=capillary_pressure_cls,
        max_capillary_pressure=max_capillary_pressure_cls,
        van_genuchten_pg=van_genuchten_pg_cls,
        van_genuchten_ng=van_genuchten_ng_cls,
        skjaeveland_nw_pc_coef=skjaeveland_nw_pc_coef_cls,
        skjaeveland_nw_pc_pwr=skjaeveland_nw_pc_pwr_cls,
        skjaeveland_wet_pc_coef=skjaeveland_wet_pc_coef_cls,
        skjaeveland_wet_pc_pwr=skjaeveland_wet_pc_pwr_cls,
        brooks_corey_pe=brooks_corey_pe_cls,
        brooks_corey_ng=brooks_corey_ng_cls,
        leverett_con_ang=leverett_con_ang_cls,
        rp_cbox_p1=rp_cbox_p1_cls,
        rp_edit_p1=rp_edit_p1_cls,
        rel_perm_tabular_p1=rel_perm_tabular_p1_cls,
        rel_perm_table_p1=rel_perm_table_p1_cls,
        rel_perm_satw_p1=rel_perm_satw_p1_cls,
        rel_perm_rp_p1=rel_perm_rp_p1_cls,
        rp_cbox_p2=rp_cbox_p2_cls,
        rp_edit_p2=rp_edit_p2_cls,
        rel_perm_tabular_p2=rel_perm_tabular_p2_cls,
        rel_perm_table_p2=rel_perm_table_p2_cls,
        rel_perm_satw_p2=rel_perm_satw_p2_cls,
        rel_perm_rp_p2=rel_perm_rp_p2_cls,
        wetting_phase=wetting_phase_cls,
        non_wetting_phase=non_wetting_phase_cls,
        equib_thermal=equib_thermal_cls,
        non_equib_thermal=non_equib_thermal_cls,
        solid_material=solid_material_cls,
        area_density=area_density_cls,
        heat_transfer_coeff=heat_transfer_coeff_cls,
        fanzone=fanzone_cls,
        fan_zone_list=fan_zone_list_cls,
        fan_thickness=fan_thickness_cls,
        fan_hub_rad=fan_hub_rad_cls,
        fan_tip_rad=fan_tip_rad_cls,
        fan_x_origin=fan_x_origin_cls,
        fan_y_origin=fan_y_origin_cls,
        fan_z_origin=fan_z_origin_cls,
        fan_rot_dir=fan_rot_dir_cls,
        fan_opert_angvel=fan_opert_angvel_cls,
        fan_inflection_point=fan_inflection_point_cls,
        limit_flow_fan=limit_flow_fan_cls,
        max_flow_rate=max_flow_rate_cls,
        min_flow_rate=min_flow_rate_cls,
        tan_source_term=tan_source_term_cls,
        rad_source_term=rad_source_term_cls,
        axial_source_term=axial_source_term_cls,
        fan_axial_source_method=fan_axial_source_method_cls,
        fan_pre_jump=fan_pre_jump_cls,
        fan_curve_fit=fan_curve_fit_cls,
        fan_poly_order=fan_poly_order_cls,
        fan_ini_flow=fan_ini_flow_cls,
        fan_test_angvel=fan_test_angvel_cls,
        fan_test_temp=fan_test_temp_cls,
        read_fan_curve=read_fan_curve_cls,
        reaction_mechs=reaction_mechs_cls,
        react=react_cls,
        surface_volume_ratio=surface_volume_ratio_cls,
        electrolyte=electrolyte_cls,
        mp_compressive_beta_max=mp_compressive_beta_max_cls,
        mp_boiling_zone=mp_boiling_zone_cls,
        numerical_beach=numerical_beach_cls,
        beach_id=beach_id_cls,
        beach_multi_dir=beach_multi_dir_cls,
        beach_damp_type=beach_damp_type_cls,
        beach_inlet_bndr=beach_inlet_bndr_cls,
        beach_fs_level=beach_fs_level_cls,
        beach_bottom_level=beach_bottom_level_cls,
        beach_dir_ni=beach_dir_ni_cls,
        beach_dir_nj=beach_dir_nj_cls,
        beach_dir_nk=beach_dir_nk_cls,
        beach_damp_len_spec=beach_damp_len_spec_cls,
        beach_wave_len=beach_wave_len_cls,
        beach_len_factor=beach_len_factor_cls,
        beach_start_point=beach_start_point_cls,
        beach_end_point=beach_end_point_cls,
        beach_dir_list=beach_dir_list_cls,
        beach_damp_relative=beach_damp_relative_cls,
        beach_damp_resist_lin=beach_damp_resist_lin_cls,
        beach_damp_resist=beach_damp_resist_cls,
        porous_structure=porous_structure_cls,
        structure_material=structure_material_cls,
        anisotropic_spe_diff=anisotropic_spe_diff_cls,
        spe_diff_xx=spe_diff_xx_cls,
        spe_diff_xy=spe_diff_xy_cls,
        spe_diff_xz=spe_diff_xz_cls,
        spe_diff_yx=spe_diff_yx_cls,
        spe_diff_yy=spe_diff_yy_cls,
        spe_diff_yz=spe_diff_yz_cls,
        spe_diff_zx=spe_diff_zx_cls,
        spe_diff_zy=spe_diff_zy_cls,
        spe_diff_zz=spe_diff_zz_cls,
    )

    return_type = "<object object at 0x7fd82c0dd710>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_2 import enable as enable_cls
from .options_3 import options as options_cls

class multi_phase_setting(Group):
    """
    'multi_phase_setting' child.
    """

    fluent_name = "multi-phase-setting"

    child_names = \
        ['enable', 'options']

    _child_classes = dict(
        enable=enable_cls,
        options=options_cls,
    )

    return_type = "<object object at 0x7fd82ae39970>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .condensing_film import condensing_film as condensing_film_cls
from .all_film import all_film as all_film_cls

class film_movement(Group):
    """
    Set options for controlling the film particles movement.
    """

    fluent_name = "film-movement"

    child_names = \
        ['condensing_film', 'all_film']

    _child_classes = dict(
        condensing_film=condensing_film_cls,
        all_film=all_film_cls,
    )

    return_type = "<object object at 0x7fb66c2e1590>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class trim_option(Integer):
    """
    Select Trimming Option:
    
     - Enter 0 if no trimming is required 
     - Enter 1 if trimming of collective pitch is required 
     - Enter 2 if trimming of cyclic pitch angles are required 
     - Enter 3 if trimming of both collective and cyclic pitch angles are required 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "trim-option"

    return_type = "<object object at 0x7fb66c2e1ce0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .initialization_type import initialization_type as initialization_type_cls
from .reference_frame_1 import reference_frame as reference_frame_cls
from .defaults import defaults as defaults_cls
from .fmg_options import fmg_options as fmg_options_cls
from .localized_turb_init import localized_turb_init as localized_turb_init_cls
from .hybrid_init_options import hybrid_init_options as hybrid_init_options_cls
from .patch import patch as patch_cls
from .open_channel_auto_init import open_channel_auto_init as open_channel_auto_init_cls
from .fmg_initialization import fmg_initialization as fmg_initialization_cls
from .initialize import initialize as initialize_cls
from .compute_defaults import compute_defaults as compute_defaults_cls
from .fmg_initialize import fmg_initialize as fmg_initialize_cls
from .standard_initialize import standard_initialize as standard_initialize_cls
from .hybrid_initialize import hybrid_initialize as hybrid_initialize_cls
from .list_defaults import list_defaults as list_defaults_cls
from .init_turb_vel_fluctuations import init_turb_vel_fluctuations as init_turb_vel_fluctuations_cls
from .init_flow_statistics import init_flow_statistics as init_flow_statistics_cls
from .show_iterations_sampled import show_iterations_sampled as show_iterations_sampled_cls
from .show_time_sampled import show_time_sampled as show_time_sampled_cls
from .dpm_reset import dpm_reset as dpm_reset_cls
from .lwf_reset import lwf_reset as lwf_reset_cls
from .init_acoustics_options import init_acoustics_options as init_acoustics_options_cls
from .levelset_auto_init import levelset_auto_init as levelset_auto_init_cls

class initialization(Group):
    """
    'initialization' child.
    """

    fluent_name = "initialization"

    child_names = \
        ['initialization_type', 'reference_frame', 'defaults', 'fmg_options',
         'localized_turb_init', 'hybrid_init_options', 'patch',
         'open_channel_auto_init', 'fmg_initialization']

    command_names = \
        ['initialize', 'compute_defaults', 'fmg_initialize',
         'standard_initialize', 'hybrid_initialize', 'list_defaults',
         'init_turb_vel_fluctuations', 'init_flow_statistics',
         'show_iterations_sampled', 'show_time_sampled', 'dpm_reset',
         'lwf_reset', 'init_acoustics_options', 'levelset_auto_init']

    _child_classes = dict(
        initialization_type=initialization_type_cls,
        reference_frame=reference_frame_cls,
        defaults=defaults_cls,
        fmg_options=fmg_options_cls,
        localized_turb_init=localized_turb_init_cls,
        hybrid_init_options=hybrid_init_options_cls,
        patch=patch_cls,
        open_channel_auto_init=open_channel_auto_init_cls,
        fmg_initialization=fmg_initialization_cls,
        initialize=initialize_cls,
        compute_defaults=compute_defaults_cls,
        fmg_initialize=fmg_initialize_cls,
        standard_initialize=standard_initialize_cls,
        hybrid_initialize=hybrid_initialize_cls,
        list_defaults=list_defaults_cls,
        init_turb_vel_fluctuations=init_turb_vel_fluctuations_cls,
        init_flow_statistics=init_flow_statistics_cls,
        show_iterations_sampled=show_iterations_sampled_cls,
        show_time_sampled=show_time_sampled_cls,
        dpm_reset=dpm_reset_cls,
        lwf_reset=lwf_reset_cls,
        init_acoustics_options=init_acoustics_options_cls,
        levelset_auto_init=levelset_auto_init_cls,
    )

    return_type = "<object object at 0x7fb5f6197c90>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .disk_origin_x import disk_origin_x as disk_origin_x_cls
from .disk_origin_y import disk_origin_y as disk_origin_y_cls
from .disk_origin_z import disk_origin_z as disk_origin_z_cls

class disk_origin(Group):
    """
    Menu to define the disk center coordinates.
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "disk-origin"

    child_names = \
        ['disk_origin_x', 'disk_origin_y', 'disk_origin_z']

    _child_classes = dict(
        disk_origin_x=disk_origin_x_cls,
        disk_origin_y=disk_origin_y_cls,
        disk_origin_z=disk_origin_z_cls,
    )

    return_type = "<object object at 0x7fc5c18a4ed0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .bitrate_scale import bitrate_scale as bitrate_scale_cls
from .enable_h264 import enable_h264 as enable_h264_cls
from .bitrate import bitrate as bitrate_cls
from .compression_method import compression_method as compression_method_cls
from .keyframe import keyframe as keyframe_cls

class advance_quality(Group):
    fluent_name = ...
    child_names = ...
    bitrate_scale: bitrate_scale_cls = ...
    enable_h264: enable_h264_cls = ...
    bitrate: bitrate_cls = ...
    compression_method: compression_method_cls = ...
    keyframe: keyframe_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .expert_3 import expert as expert_cls
from .relative_convergence_criterion import relative_convergence_criterion as relative_convergence_criterion_cls
from .max_iter_per_timestep_count import max_iter_per_timestep_count as max_iter_per_timestep_count_cls

class acoustics_wave_eqn_controls(Group):
    fluent_name = ...
    child_names = ...
    expert: expert_cls = ...
    relative_convergence_criterion: relative_convergence_criterion_cls = ...
    max_iter_per_timestep_count: max_iter_per_timestep_count_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_1 import name as name_cls
from .title import title as title_cls
from .temporary import temporary as temporary_cls
from .graphics_objects import graphics_objects as graphics_objects_cls
from .display_state_name import display_state_name as display_state_name_cls
from .display_3 import display as display_cls

class scene_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    title: title_cls = ...
    temporary: temporary_cls = ...
    graphics_objects: graphics_objects_cls = ...
    display_state_name: display_state_name_cls = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .project_filename import project_filename as project_filename_cls
from .load_case import load_case as load_case_cls

class open(Command):
    fluent_name = ...
    argument_names = ...
    project_filename: project_filename_cls = ...
    load_case: load_case_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .kw_low_re_correction import kw_low_re_correction as kw_low_re_correction_cls
from .kw_shear_correction import kw_shear_correction as kw_shear_correction_cls
from .turb_compressibility import turb_compressibility as turb_compressibility_cls

class k_omega_options(Group):
    """
    'k_omega_options' child.
    """

    fluent_name = "k-omega-options"

    child_names = \
        ['kw_low_re_correction', 'kw_shear_correction',
         'turb_compressibility']

    _child_classes = dict(
        kw_low_re_correction=kw_low_re_correction_cls,
        kw_shear_correction=kw_shear_correction_cls,
        turb_compressibility=turb_compressibility_cls,
    )

    return_type = "<object object at 0x7fc5c18a5840>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .method import method as method_cls
from .number_of_coeff import number_of_coeff as number_of_coeff_cls
from .function_of import function_of as function_of_cls
from .coefficients import coefficients as coefficients_cls
from .constant import constant as constant_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls

class viscosity_ratio(Group):
    fluent_name = ...
    child_names = ...
    method: method_cls = ...
    number_of_coeff: number_of_coeff_cls = ...
    function_of: function_of_cls = ...
    coefficients: coefficients_cls = ...
    constant: constant_cls = ...
    piecewise_polynomial: piecewise_polynomial_cls = ...
    piecewise_linear: piecewise_linear_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .boundaries_child import boundaries_child


class boundaries(NamedObject[boundaries_child], CreatableNamedObjectMixinOld[boundaries_child]):
    """
    'boundaries' child.
    """

    fluent_name = "boundaries"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy']

    _child_classes = dict(
        delete=delete_cls,
        list=list_cls,
        list_properties=list_properties_cls,
        make_a_copy=make_a_copy_cls,
    )

    child_object_type: boundaries_child = boundaries_child
    """
    child_object_type of boundaries.
    """
    return_type = "<object object at 0x7f766ab82c60>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_3 import option as option_cls
from .value import value as value_cls
from .profile_name import profile_name as profile_name_cls
from .field_name import field_name as field_name_cls
from .udf import udf as udf_cls

class velocity_ratio(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    value: value_cls = ...
    profile_name: profile_name_cls = ...
    field_name: field_name_cls = ...
    udf: udf_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_14 import enable as enable_cls
from .disable_1 import disable as disable_cls
from .copy_3 import copy as copy_cls
from .delete_2 import delete as delete_cls
from .export_1 import export as export_cls
from .import__1 import import_ as import__cls

class execute_commands(Group):
    fluent_name = ...
    command_names = ...

    def enable(self, command_name: str):
        """
        Enable an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def disable(self, command_name: str):
        """
        Disable an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def copy(self, command_name: str):
        """
        Copy an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def delete(self, command_name: str):
        """
        Delete an execute-command.
        
        Parameters
        ----------
            command_name : str
                'command_name' child.
        
        """

    def export(self, command_name: List[str], tsv_file_name: str):
        """
        Export execute-commands to a TSV file.
        
        Parameters
        ----------
            command_name : List
                'command_name' child.
            tsv_file_name : str
                'tsv_file_name' child.
        
        """

    def import_(self, tsv_file_name: str):
        """
        Import execute-commands from a TSV file.
        
        Parameters
        ----------
            tsv_file_name : str
                'tsv_file_name' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .coefficient import coefficient as coefficient_cls
from .update_dissipation import update_dissipation as update_dissipation_cls
from .update_viscous import update_viscous as update_viscous_cls

class multi_stage_child(Group):
    """
    'child_object_type' of multi_stage.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['coefficient', 'update_dissipation', 'update_viscous']

    _child_classes = dict(
        coefficient=coefficient_cls,
        update_dissipation=update_dissipation_cls,
        update_viscous=update_viscous_cls,
    )

    return_type = "<object object at 0x7fc55434f050>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .minimum import minimum as minimum_cls
from .maximum import maximum as maximum_cls
from .number_of_coefficients import number_of_coefficients as number_of_coefficients_cls
from .coefficients import coefficients as coefficients_cls

class piecewise_polynomial_child(Group):
    fluent_name = ...
    child_names = ...
    minimum: minimum_cls = ...
    maximum: maximum_cls = ...
    number_of_coefficients: number_of_coefficients_cls = ...
    coefficients: coefficients_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .all_len_modified import all_len_modified as all_len_modified_cls
from .des_limiter_option import des_limiter_option as des_limiter_option_cls

class des_options(Group):
    fluent_name = ...
    child_names = ...
    all_len_modified: all_len_modified_cls = ...
    des_limiter_option: des_limiter_option_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_1 import name as name_cls
from .transparency import transparency as transparency_cls
from .colormap_position import colormap_position as colormap_position_cls
from .colormap_left import colormap_left as colormap_left_cls
from .colormap_bottom import colormap_bottom as colormap_bottom_cls
from .colormap_width import colormap_width as colormap_width_cls
from .colormap_height import colormap_height as colormap_height_cls

class graphics_objects_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    transparency: transparency_cls = ...
    colormap_position: colormap_position_cls = ...
    colormap_left: colormap_left_cls = ...
    colormap_bottom: colormap_bottom_cls = ...
    colormap_width: colormap_width_cls = ...
    colormap_height: colormap_height_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .theory import theory as theory_cls
from .wave_ht import wave_ht as wave_ht_cls
from .wave_len import wave_len as wave_len_cls
from .phase_diff import phase_diff as phase_diff_cls
from .heading_angle import heading_angle as heading_angle_cls

class wave_list_child(Group):
    fluent_name = ...
    child_names = ...
    theory: theory_cls = ...
    wave_ht: wave_ht_cls = ...
    wave_len: wave_len_cls = ...
    phase_diff: phase_diff_cls = ...
    heading_angle: heading_angle_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .min_diam import min_diam as min_diam_cls
from .max_diam import max_diam as max_diam_cls
from .mean_diam import mean_diam as mean_diam_cls
from .spread import spread as spread_cls
from .number_of_diameters import number_of_diameters as number_of_diameters_cls

class rosin_rammler_settings(Group):
    """
    'rosin_rammler_settings' child.
    """

    fluent_name = "rosin-rammler-settings"

    child_names = \
        ['min_diam', 'max_diam', 'mean_diam', 'spread', 'number_of_diameters']

    _child_classes = dict(
        min_diam=min_diam_cls,
        max_diam=max_diam_cls,
        mean_diam=mean_diam_cls,
        spread=spread_cls,
        number_of_diameters=number_of_diameters_cls,
    )

    return_type = "<object object at 0x7fc5c18a61a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_pseudo_time_method import enable_pseudo_time_method as enable_pseudo_time_method_cls
from .pseudo_time_scale_factor import pseudo_time_scale_factor as pseudo_time_scale_factor_cls
from .implicit_under_relaxation_factor import implicit_under_relaxation_factor as implicit_under_relaxation_factor_cls

class local_dt_child(Group):
    """
    'child_object_type' of local_dt.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['enable_pseudo_time_method', 'pseudo_time_scale_factor',
         'implicit_under_relaxation_factor']

    _child_classes = dict(
        enable_pseudo_time_method=enable_pseudo_time_method_cls,
        pseudo_time_scale_factor=pseudo_time_scale_factor_cls,
        implicit_under_relaxation_factor=implicit_under_relaxation_factor_cls,
    )

    return_type = "<object object at 0x7fb5f6194d60>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .table_name import table_name as table_name_cls
from .column_with_diameters import column_with_diameters as column_with_diameters_cls
from .column_with_number_fractions import column_with_number_fractions as column_with_number_fractions_cls
from .column_with_mass_fractions import column_with_mass_fractions as column_with_mass_fractions_cls
from .accumulated_number_fraction import accumulated_number_fraction as accumulated_number_fraction_cls
from .accumulated_mass_fraction import accumulated_mass_fraction as accumulated_mass_fraction_cls

class tabulated_size_settings(Group):
    fluent_name = ...
    child_names = ...
    table_name: table_name_cls = ...
    column_with_diameters: column_with_diameters_cls = ...
    column_with_number_fractions: column_with_number_fractions_cls = ...
    column_with_mass_fractions: column_with_mass_fractions_cls = ...
    accumulated_number_fraction: accumulated_number_fraction_cls = ...
    accumulated_mass_fraction: accumulated_mass_fraction_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .solve_tke import solve_tke as solve_tke_cls
from .wall_echo import wall_echo as wall_echo_cls

class reynolds_stress_options(Group):
    """
    'reynolds_stress_options' child.
    """

    fluent_name = "reynolds-stress-options"

    child_names = \
        ['solve_tke', 'wall_echo']

    _child_classes = dict(
        solve_tke=solve_tke_cls,
        wall_echo=wall_echo_cls,
    )

    return_type = "<object object at 0x7fd8b12a1270>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .recommended_defaults_for_existing_cases import recommended_defaults_for_existing_cases as recommended_defaults_for_existing_cases_cls
from .revert_to_pre_r20_1_default_settings import revert_to_pre_r20_1_default_settings as revert_to_pre_r20_1_default_settings_cls

class default_controls(Group):
    fluent_name = ...
    child_names = ...
    recommended_defaults_for_existing_cases: recommended_defaults_for_existing_cases_cls = ...
    revert_to_pre_r20_1_default_settings: revert_to_pre_r20_1_default_settings_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .convective_heat_transfer import convective_heat_transfer as convective_heat_transfer_cls
from .include_convective_heat_transfer import include_convective_heat_transfer as include_convective_heat_transfer_cls
from .film_movement import film_movement as film_movement_cls
from .lwf_particle_inclusion_in_dpm_concentration_enabled import lwf_particle_inclusion_in_dpm_concentration_enabled as lwf_particle_inclusion_in_dpm_concentration_enabled_cls
from .wall_film_temperature_limiter import wall_film_temperature_limiter as wall_film_temperature_limiter_cls

class wall_film(Group):
    """
    'wall_film' child.
    """

    fluent_name = "wall-film"

    child_names = \
        ['convective_heat_transfer', 'include_convective_heat_transfer',
         'film_movement',
         'lwf_particle_inclusion_in_dpm_concentration_enabled',
         'wall_film_temperature_limiter']

    _child_classes = dict(
        convective_heat_transfer=convective_heat_transfer_cls,
        include_convective_heat_transfer=include_convective_heat_transfer_cls,
        film_movement=film_movement_cls,
        lwf_particle_inclusion_in_dpm_concentration_enabled=lwf_particle_inclusion_in_dpm_concentration_enabled_cls,
        wall_film_temperature_limiter=wall_film_temperature_limiter_cls,
    )

    return_type = "<object object at 0x7fb66c2e15f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .principal_axes import principal_axes as principal_axes_cls
from .principal_values import principal_values as principal_values_cls
from .conductivity import conductivity as conductivity_cls

class principal_axes_values(Group):
    fluent_name = ...
    child_names = ...
    principal_axes: principal_axes_cls = ...
    principal_values: principal_values_cls = ...
    conductivity: conductivity_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_mesh_interface_clustering import enable_mesh_interface_clustering as enable_mesh_interface_clustering_cls
from .split_angle import split_angle as split_angle_cls
from .clustering_algorithm import clustering_algorithm as clustering_algorithm_cls
from .faces_per_cluster import faces_per_cluster as faces_per_cluster_cls
from .print_thread_clusters import print_thread_clusters as print_thread_clusters_cls

class clustering_settings(Group):
    """
    Enter clustering related settings.
    """

    fluent_name = "clustering-settings"

    child_names = \
        ['enable_mesh_interface_clustering', 'split_angle',
         'clustering_algorithm', 'faces_per_cluster']

    command_names = \
        ['print_thread_clusters']

    _child_classes = dict(
        enable_mesh_interface_clustering=enable_mesh_interface_clustering_cls,
        split_angle=split_angle_cls,
        clustering_algorithm=clustering_algorithm_cls,
        faces_per_cluster=faces_per_cluster_cls,
        print_thread_clusters=print_thread_clusters_cls,
    )

    return_type = "<object object at 0x7fb6784d91c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .options import options as options_cls
from .domain_val import domain_val as domain_val_cls
from .all_wall_zones import all_wall_zones as all_wall_zones_cls
from .wall_thread_list import wall_thread_list as wall_thread_list_cls
from .direction_vector_1 import direction_vector as direction_vector_cls
from .momentum_center import momentum_center as momentum_center_cls
from .momentum_axis import momentum_axis as momentum_axis_cls
from .pressure_coordinate import pressure_coordinate as pressure_coordinate_cls
from .coord_val import coord_val as coord_val_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
from .overwrite import overwrite as overwrite_cls

class forces(Command):
    fluent_name = ...
    argument_names = ...
    options: options_cls = ...
    domain_val: domain_val_cls = ...
    all_wall_zones: all_wall_zones_cls = ...
    wall_thread_list: wall_thread_list_cls = ...
    direction_vector: direction_vector_cls = ...
    momentum_center: momentum_center_cls = ...
    momentum_axis: momentum_axis_cls = ...
    pressure_coordinate: pressure_coordinate_cls = ...
    coord_val: coord_val_cls = ...
    write_to_file: write_to_file_cls = ...
    file_name: file_name_cls = ...
    append_data: append_data_cls = ...
    overwrite: overwrite_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .thread_number_control import thread_number_control as thread_number_control_cls
from .check_verbosity_1 import check_verbosity as check_verbosity_cls
from .partition_1 import partition as partition_cls
from .set_4 import set as set_cls
from .load_balance import load_balance as load_balance_cls
from .multidomain import multidomain as multidomain_cls
from .network_1 import network as network_cls
from .timer import timer as timer_cls
from .check_1 import check as check_cls
from .show_connectivity import show_connectivity as show_connectivity_cls
from .latency import latency as latency_cls
from .bandwidth import bandwidth as bandwidth_cls

class parallel(Group):
    """
    'parallel' child.
    """

    fluent_name = "parallel"

    child_names = \
        ['thread_number_control', 'check_verbosity', 'partition', 'set',
         'load_balance', 'multidomain', 'network', 'timer']

    command_names = \
        ['check', 'show_connectivity', 'latency', 'bandwidth']

    _child_classes = dict(
        thread_number_control=thread_number_control_cls,
        check_verbosity=check_verbosity_cls,
        partition=partition_cls,
        set=set_cls,
        load_balance=load_balance_cls,
        multidomain=multidomain_cls,
        network=network_cls,
        timer=timer_cls,
        check=check_cls,
        show_connectivity=show_connectivity_cls,
        latency=latency_cls,
        bandwidth=bandwidth_cls,
    )

    return_type = "<object object at 0x7fc53ff35bc0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_19 import phase as phase_cls
from .name_2 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .kc import kc as kc_cls
from .hc import hc as hc_cls
from .t_1 import t as t_cls
from .q_1 import q as q_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .strength import strength as strength_cls

class radiator_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    name: name_cls = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = ...
    kc: kc_cls = ...
    hc: hc_cls = ...
    t: t_cls = ...
    q: q_cls = ...
    dpm_bc_type: dpm_bc_type_cls = ...
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = ...
    reinj_inj: reinj_inj_cls = ...
    dpm_bc_udf: dpm_bc_udf_cls = ...
    strength: strength_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .method import method as method_cls
from .samp_time_period import samp_time_period as samp_time_period_cls
from .samp_time_steps import samp_time_steps as samp_time_steps_cls
from .avg_time_period import avg_time_period as avg_time_period_cls
from .avg_time_steps import avg_time_steps as avg_time_steps_cls

class statistics_controls(Command):
    fluent_name = ...
    argument_names = ...
    method: method_cls = ...
    samp_time_period: samp_time_period_cls = ...
    samp_time_steps: samp_time_steps_cls = ...
    avg_time_period: avg_time_period_cls = ...
    avg_time_steps: avg_time_steps_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list_valid_report_names import list_valid_report_names as list_valid_report_names_cls
from .define import define as define_cls
from .expr_value import expr_value as expr_value_cls
from .average_over import average_over as average_over_cls
from .old_props import old_props as old_props_cls

class expression_child(Group):
    """
    'child_object_type' of expression.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['list_valid_report_names', 'define', 'expr_value', 'average_over',
         'old_props']

    _child_classes = dict(
        list_valid_report_names=list_valid_report_names_cls,
        define=define_cls,
        expr_value=expr_value_cls,
        average_over=average_over_cls,
        old_props=old_props_cls,
    )

    return_type = "<object object at 0x7fc5542410d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .end_of_timestep import end_of_timestep as end_of_timestep_cls

class interrupt(Command):
    """
    Interrupt the iterations.
    
    Parameters
    ----------
        end_of_timestep : bool
            'end_of_timestep' child.
    
    """

    fluent_name = "interrupt"

    argument_names = \
        ['end_of_timestep']

    _child_classes = dict(
        end_of_timestep=end_of_timestep_cls,
    )

    return_type = "<object object at 0x7fc554243110>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .area import area as area_cls
from .compute_1 import compute as compute_cls
from .depth import depth as depth_cls
from .density_1 import density as density_cls
from .enthalpy import enthalpy as enthalpy_cls
from .length_val import length_val as length_val_cls
from .pressure import pressure as pressure_cls
from .temperature_1 import temperature as temperature_cls
from .yplus import yplus as yplus_cls
from .velocity import velocity as velocity_cls
from .viscosity_1 import viscosity as viscosity_cls
from .list_val import list_val as list_val_cls

class reference_values(Group):
    """
    'reference_values' child.
    """

    fluent_name = "reference-values"

    child_names = \
        ['area', 'compute', 'depth', 'density', 'enthalpy', 'length_val',
         'pressure', 'temperature', 'yplus', 'velocity', 'viscosity',
         'list_val']

    _child_classes = dict(
        area=area_cls,
        compute=compute_cls,
        depth=depth_cls,
        density=density_cls,
        enthalpy=enthalpy_cls,
        length_val=length_val_cls,
        pressure=pressure_cls,
        temperature=temperature_cls,
        yplus=yplus_cls,
        velocity=velocity_cls,
        viscosity=viscosity_cls,
        list_val=list_val_cls,
    )

    return_type = "<object object at 0x7fd82ae383d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .set_ramping_length import set_ramping_length as set_ramping_length_cls
from .number_of_timesteps import number_of_timesteps as number_of_timesteps_cls

class init_acoustics_options(Command):
    """
    'init_acoustics_options' command.
    
    Parameters
    ----------
        set_ramping_length : bool
            Enable/Disable ramping length and initialize acoustics.
        number_of_timesteps : int
            Set number of timesteps for ramping of sources.
    
    """

    fluent_name = "init-acoustics-options"

    argument_names = \
        ['set_ramping_length', 'number_of_timesteps']

    _child_classes = dict(
        set_ramping_length=set_ramping_length_cls,
        number_of_timesteps=number_of_timesteps_cls,
    )

    return_type = "<object object at 0x7fd82ae3aa40>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .f_length import f_length as f_length_cls
from .re_theta_c import re_theta_c as re_theta_c_cls
from .re_theta_t import re_theta_t as re_theta_t_cls

class user_defined_transition(Group):
    fluent_name = ...
    child_names = ...
    f_length: f_length_cls = ...
    re_theta_c: re_theta_c_cls = ...
    re_theta_t: re_theta_t_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .design_points import design_points as design_points_cls

class clear_generated_data(Command):
    """
    Clear Generated Data.
    
    Parameters
    ----------
        design_points : List
            'design_points' child.
    
    """

    fluent_name = "clear-generated-data"

    argument_names = \
        ['design_points']

    _child_classes = dict(
        design_points=design_points_cls,
    )

    return_type = "<object object at 0x7fb5f5f73a50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .minimum_1 import minimum as minimum_cls
from .maximum_1 import maximum as maximum_cls
from .number_of_coeff import number_of_coeff as number_of_coeff_cls
from .coefficients_1 import coefficients as coefficients_cls

class piecewise_polynomial_child(Group):
    """
    'child_object_type' of piecewise_polynomial.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['minimum', 'maximum', 'number_of_coeff', 'coefficients']

    _child_classes = dict(
        minimum=minimum_cls,
        maximum=maximum_cls,
        number_of_coeff=number_of_coeff_cls,
        coefficients=coefficients_cls,
    )

    return_type = "<object object at 0x7fb5f6eef860>"
